searchNodes=[{"doc":"Send commands to Z-Wave devicesGrizzly provides the send_command function as the way to send a command to Z-Wave devices.The send_command function takes the node id that you are trying to send a command to, the command name, and optionally command arguments and command options.A basic command that has no options or arguments looks like this:Grizzly.send_command(node_id, :switch_binary_get)A command with command arguments:Grizzly.send_command(node_id, :switch_binary_set, value: :off)Also, a command can have options. Namely, :timeout (default 5_000) and :retries (default 2).Grizzly.send_command(node_id, :switch_binary_get, [], timeout: 10_000, retries: 5)The send_command returns one 4 values::ok - the command was sent and everything is okay{:ok, Command.t()} - the command was sent and the Z-Wave device responded with another command (probably some type of report){:error, :including} - current the Z-Wave controller is adding or removing a device and commands cannot be processed right now{:error, :firmware_updating} - current the Z-Wave controller is updating firmware and commands cannot be processed right now{:error, reason} - there was some other reason for an error, two common ones are: :timeout and :nack_response{:queued, reference, seconds} - the node is a sleeping node so the controller queued the command and expects the command to be sent in after the reported seconds have passed.For a more detailed explanation of the responses from a send_command call see the typedoc for Grizzly.send_command_response().","ref":"Grizzly.html","title":"Grizzly","type":"module"},{"doc":"Send a command to the node via the node id","ref":"Grizzly.html#send_command/4","title":"Grizzly.send_command/4","type":"function"},{"doc":"Subscribe to a command event from a Z-Wave device","ref":"Grizzly.html#subscribe_command/1","title":"Grizzly.subscribe_command/1","type":"function"},{"doc":"Subscribe to many events from a Z-Wave device","ref":"Grizzly.html#subscribe_commands/1","title":"Grizzly.subscribe_commands/1","type":"function"},{"doc":"Unsubscribe to an event","ref":"Grizzly.html#unsubscribe_command/1","title":"Grizzly.unsubscribe_command/1","type":"function"},{"doc":"","ref":"Grizzly.html#t:command/0","title":"Grizzly.command/0","type":"type"},{"doc":"","ref":"Grizzly.html#t:command_opt/0","title":"Grizzly.command_opt/0","type":"type"},{"doc":"","ref":"Grizzly.html#t:node_id/0","title":"Grizzly.node_id/0","type":"type"},{"doc":"The response from sending a Z-Wave commandWhen everything is okay you will either back an :ok or a {:ok, %Grizzly.Zwave.Command{}}. The Z-Wave Command data structure provides a consistent interface to all the Z-Wave commands. For more information see Grizzly.ZWave.Command module.In Grizzly :ok does not mean the Z-Wave node received and processed your command. Rather it only means that the command was received. If you want to make sure the device processed your command correctly you will have to issue another command to get the value you just set and verify it that way.When there are errors the response will be in the pattern of {:error, reason}.Three reasons that Grizzly supports for all commands are :timeout, :nack_response, and :including.If your command takes awhile to run you adjust the :timeout value with the :timeout command option using Grizzly.send_command/4.A :nack_response normally means that the Z-Wave node that you were trying to send a command to is unreachable and did not receive your command at all. This could mean that the Z-Wave network is overloaded and you should reissue the command, the device is too far from the controller, or the device is no longer part of the Z-Wave network.Grizzly by default will try a command 3 times before sending returning a :nack_response. This is configurable via the :retries command option in the Grizzly.send_command/4 function. This is useful if you are going to have a known spike in Z-Wave traffic.In you receive the reason for the error to be :including that means the controller is in an inclusion state and your command will be dropped if we tried to send it. So we won't allow sending a Z-Wave command during an inclusion. It's best to wait and try again once your application is done trying to include.","ref":"Grizzly.html#t:send_command_response/0","title":"Grizzly.send_command_response/0","type":"type"},{"doc":"","ref":"Grizzly.html#t:seq_number/0","title":"Grizzly.seq_number/0","type":"type"},{"doc":"Behaviour for how commands should handle incoming Z-Wave messages","ref":"Grizzly.CommandHandler.html","title":"Grizzly.CommandHandler","type":"behaviour"},{"doc":"","ref":"Grizzly.CommandHandler.html#c:handle_ack/1","title":"Grizzly.CommandHandler.handle_ack/1","type":"callback"},{"doc":"","ref":"Grizzly.CommandHandler.html#c:handle_command/2","title":"Grizzly.CommandHandler.handle_command/2","type":"callback"},{"doc":"","ref":"Grizzly.CommandHandler.html#c:init/1","title":"Grizzly.CommandHandler.init/1","type":"callback"},{"doc":"","ref":"Grizzly.CommandHandler.html#t:handle_response/0","title":"Grizzly.CommandHandler.handle_response/0","type":"type"},{"doc":"This handler is useful for most set commands that only needs to be acknowledged","ref":"Grizzly.CommandHandlers.AckResponse.html","title":"Grizzly.CommandHandlers.AckResponse","type":"module"},{"doc":"Handler for working with reports that could take many report frames to completeThis handler will handle aggregating the responses into one report command for ease of consumption by callers.","ref":"Grizzly.CommandHandlers.AggregateReport.html","title":"Grizzly.CommandHandlers.AggregateReport","type":"module"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_ack/1.","ref":"Grizzly.CommandHandlers.AggregateReport.html#handle_ack/1","title":"Grizzly.CommandHandlers.AggregateReport.handle_ack/1","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_command/2.","ref":"Grizzly.CommandHandlers.AggregateReport.html#handle_command/2","title":"Grizzly.CommandHandlers.AggregateReport.handle_command/2","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.init/1.","ref":"Grizzly.CommandHandlers.AggregateReport.html#init/1","title":"Grizzly.CommandHandlers.AggregateReport.init/1","type":"function"},{"doc":"","ref":"Grizzly.CommandHandlers.AggregateReport.html#t:opt/0","title":"Grizzly.CommandHandlers.AggregateReport.opt/0","type":"type"},{"doc":"","ref":"Grizzly.CommandHandlers.AggregateReport.html#t:state/0","title":"Grizzly.CommandHandlers.AggregateReport.state/0","type":"type"},{"doc":"This handle is useful for when you want to wait for a particular report from the Z-Wave network. Most GET commands can use this handler.","ref":"Grizzly.CommandHandlers.WaitReport.html","title":"Grizzly.CommandHandlers.WaitReport","type":"module"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_ack/1.","ref":"Grizzly.CommandHandlers.WaitReport.html#handle_ack/1","title":"Grizzly.CommandHandlers.WaitReport.handle_ack/1","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.handle_command/2.","ref":"Grizzly.CommandHandlers.WaitReport.html#handle_command/2","title":"Grizzly.CommandHandlers.WaitReport.handle_command/2","type":"function"},{"doc":"Callback implementation for Grizzly.CommandHandler.init/1.","ref":"Grizzly.CommandHandlers.WaitReport.html#init/1","title":"Grizzly.CommandHandlers.WaitReport.init/1","type":"function"},{"doc":"","ref":"Grizzly.CommandHandlers.WaitReport.html#t:opt/0","title":"Grizzly.CommandHandlers.WaitReport.opt/0","type":"type"},{"doc":"","ref":"Grizzly.CommandHandlers.WaitReport.html#t:state/0","title":"Grizzly.CommandHandlers.WaitReport.state/0","type":"type"},{"doc":"Behaviour for handling incoming commands during the firmware update processWhen you initialize a firmware update process you can pass the :handler option to the function which can either be the a pid (defaults to caller pid) or a module that implements this behaviour.The report this callback function will most want to handle is:Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport It indicates whether the formware update was initiated successfully.Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport It is sent by the target device once the firmware update completes, successfully or in failure.The callback might also want to be aware of:Grizzly.ZWave.Commands.FirmwareUpdateMDGet It is sent by the target device when it wants more firmware image fragmentsGrizzly.ZWave.Commands.FirmwareMDReport It might be sent by the target device during the upgrade to modify the maximum fragment size.Grizzly.ZWave.Commands.FirmwareUpdateActivationReport It is sent by the target device in response to an activation request and gives the activation status.","ref":"Grizzly.FirmwareUpdateHandler.html","title":"Grizzly.FirmwareUpdateHandler","type":"behaviour"},{"doc":"","ref":"Grizzly.FirmwareUpdateHandler.html#c:handle_command/2","title":"Grizzly.FirmwareUpdateHandler.handle_command/2","type":"callback"},{"doc":"Module for upgrading firmware on target devices.Required options:manufacturer_id - The unique id indentifying the manufacturer of the target devicefirmware_id - The id of the current firmwareOther options:device_id - Node id of the device to be updated. Defaults to 1 (controller)firmware_target - The firwmare target id. Defaults to 0 (the ZWave chip)max_fragment_size - The maximum number of bytes that will be transmitted at a time. Defaults to 2048.hardware_version - The current hardware version of the device to be updated. Defaults to 0.activation_may_be_delayed? - Whether it is permitted for the device may delay the actual firmware update. Defaults to false.handler - The process that will receive callbacks. Defaults to the caller.any()The firmware update process is as follows:Grizzly sends a firmware_md_get command to the target device to get the manufacturer_id, hardware_id, max_fragment size, among other info needed to specify a firmware update request. The info is returned via a firmware_md_report command.Grizzly uses this info to send a firmware_update_md_request command to the target device, telling it to initiate the image uploading process. The checksum of the entire firmware image is added to the request. The target device says yeah or nay via a firmware_update_md_request_report command.If the target device agrees to have its firmware updated, it next sends a first firmware_update_md_get command to Grizzly asking for a number_of_reports (a bunch of firmware image fragment uploads) starting at fragment report_number.Grizzly responds by sending the requested series of firmware_update_md_report commands to the target device, each one containing a firmware image fragment, with a checksum for the command.Once a series of uploads is completed, the target device either asks for more fragments via another firmware_update_md_get command, or it sends a firmware_update_md_status_report command either to cancel the yet incomplete upload (bad command checksums!), or to announce that the update has completed either successfully (with some info about what happens next) or in failure (invalid overall image checksum!).As part of a successful firmware_update_md_status_report command, the target device tells Grizzly whether the new firmware needs to be activated. If it does, Grizzly would then be expected to send a firmware_update_activation_set command which success is reported by the target device via a firmware_update_activation_report command.","ref":"Grizzly.FirmwareUpdates.html","title":"Grizzly.FirmwareUpdates","type":"module"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#firmware_image_fragment_count/0","title":"Grizzly.FirmwareUpdates.firmware_image_fragment_count/0","type":"function"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#firmware_update_running?/0","title":"Grizzly.FirmwareUpdates.firmware_update_running?/0","type":"function"},{"doc":"Starts the firmware update process","ref":"Grizzly.FirmwareUpdates.html#start_firmware_update/2","title":"Grizzly.FirmwareUpdates.start_firmware_update/2","type":"function"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#t:image_path/0","title":"Grizzly.FirmwareUpdates.image_path/0","type":"type"},{"doc":"","ref":"Grizzly.FirmwareUpdates.html#t:opt/0","title":"Grizzly.FirmwareUpdates.opt/0","type":"type"},{"doc":"Behaviour for handling incoming commands during the inclusion processDuring the inclusion process different Z-Wave commands can be exchanged asynchronously. One way to handle this is by wrapping Grizzly.Inclusions in a GenServer, but that is a lot of work for something Grizzly can provide out of the box.When you initialize an inclusion process you can pass the :handler option to the command-handling function which can either be the a pid (defaults to caller pid) or a module that implements this behaviour.These reports this callback function will want to handle are:Grizzly.ZWave.Commands.NodeAddStatusGrizzly.ZWave.Commands.NodeRemoveStatusGrizzly.ZWave.Commands.NodeAddDSKReportGrizzly.ZWave.Commands.NodeAddKeysReportIf you are not handling S2 devices the last two can be ignored until you are ready to provide support them. The timeout-handling function will want to handle timeouts, particularly on state :dsk_requested, if you are handling S2-authenticated devices.","ref":"Grizzly.InclusionHandler.html","title":"Grizzly.InclusionHandler","type":"behaviour"},{"doc":"","ref":"Grizzly.InclusionHandler.html#c:handle_command/2","title":"Grizzly.InclusionHandler.handle_command/2","type":"callback"},{"doc":"","ref":"Grizzly.InclusionHandler.html#c:handle_timeout/2","title":"Grizzly.InclusionHandler.handle_timeout/2","type":"callback"},{"doc":"Module for adding and removing Z-Wave nodesIn Z-Wave the term &quot;inclusions&quot; means two things:Adding a new Z-Wave device to the Z-Wave NetworkRemoving a Z-Wave device to the Z-Wave NetworkIn practice though it is more common to speak about adding a Z-Wave node in the context of &quot;including&quot; and removing an Z-Wave mode in the context of &quot;excluding.&quot; This module provides functionality for working will all contexts of inclusion, both adding and removing.Adding a Z-Wave Node (including)When adding a device that does not required any security authentication is as simple as calling Grizzly.Inclusions.add_node/0.iex&gt; Grizzly.Inclusions.add_node() :okAfter starting the inclusion on the controller, which the above function does, you can then put your device into inclusion as well. From here the new device and your controller will communicate and if all goes well you should receive a message in the form of {:grizzly, :inclusion, NodeAddStatus} where the the NodeAddStatus is a Z-Wave command the contains information about the inclusion status (status, node id, supported command classes, security levels, etc.). See Grizzly.ZWave.Commands.NodeAddStatus for more information about the values in that command. For example:defmodule MyInclusionServer do use GenServer require Logger alias Grizzly.Inclusions alias Grizzly.ZWave.Command def start_link(_) do GenServer.start_link(__MODULE__, nil) end def add_node(pid) do GenServer.call(pid, :add_node) end def init(_) do {:ok, nil} end def handle_call(:add_node, _from, state) do :ok = Inclusions.add_node() {:reply, :ok, state} end def handle_info({:grizzly, :inclusion, command}, state) do case Command.param!(command, :status) do :done -&gt; node_id = Command.param!(command, :node_id) Logger.info(&quot;Node added with id: &quot; &lt;&gt; node_id) :failed -&gt; Logger.warn(&quot;Adding node failed :(&quot;) :security_failed -&gt; node_id = Command.param!(command, :node_id) Logger.warn(&quot;Node added with id: &quot; &lt;&gt; node_id &lt;&gt; &quot;but the security failed&quot;) end {:noreply, state} end endStop Adding a NodeIf you need you need to stop trying to add a node to the Z-Wave network you can use the Grizzly.Inclusions.remove_node/0 function.This should stop the controller from trying to add a node and return it to a normal functions state.SecurityThere are five security levels in Z-Wave: unsecured, S0, S2 unauthenticated, S2 authenticated, and S2 access control. The first 2 requires nothing special from the calling process to able to use, as the controller and the including node will figure out which security scheme to use.S2The process of adding an S2 device is a little more involved. The process is the same up until right after you put the including node into the inclusion mode. At that point including will request security keys, which really means it tells you which S2 security scheme it supports. You then use the Grizzly.Inclusions.grant_keys/1 function to pass a list of allowed security schemes.After that the node will response with a NodeAddDSKReport where it reports the DSK and something called the :dsk_input_length. If the input length is 0, that means it is trying to do S2 unauthenticated inclusion. You can just call Grizzly.Inclusions.set_input_dsk/0 function and the rest of the inclusion process should continue until complete.If the :dsk_input_length has number, normally will be 2 that means the including device is requesting a 5 digit digit pin that is normally found on a label somewhere on the physical device it.From here you can call Grizzly.Inclusions.set_input_dsk/1 with the 5 digit integer as the argument. The inclusion process should continue until complete.Removing a Z-Wave Node (excluding)To remove a Z-Wave node from the network the Grizzly.Inclusions.remove_node/0 will start an inclusion process for removing a Z-Wave node. After calling this function you can place your device into the inclusion (normally the same way you included the device is the way the device is excluded) mode. At the end of the exclusion the NodeRemoveStatus command is received and can be inspected for success of failure.Removed Node ID 0?Any Z-Wave controller can excluded a device from another controller. In practice this means your Z-Wave controller can make a device &quot;forget&quot; the controller it is currently attached to. Most the time Z-Wave products will have you excluded your device and then included just to make sure the including node isn't connected to another Z-Wave controller.When this happens you will a successful NodeRemoveStatusReport but the node id will be 0. This is consider successful and most the time intend.Stopping Remove Node ProcessTo stop the removal inclusion process on your controller you can call the Grizzly.Inclusions.remove_node_stop/0 function.Inclusion HandlerTo tie into the inclusion process we default to sending messages to the calling process. However, there is a better way to tie into this system.When starting any inclusion process you can pass the :handler option which can be either another pid or a module that implements the Grizzly.InclusionHandler behaviour, or a tuple with the module and callback arguments.A basic implementation might look like:defmodule MyApp.InclusionHandler do @behaviour Grizzly.InclusionHandler require Logger def handle_command(command, opts) do Logger.info(&quot;Got command: &quot; &lt;&gt; command.name &lt;&gt; &quot; with callback arguments &quot; &lt;&gt; inspect opts) :ok end endThis is recommended for applications using Grizzly over a GenServer that wraps Grizzly.Inclusions.","ref":"Grizzly.Inclusions.html","title":"Grizzly.Inclusions","type":"module"},{"doc":"Start the process to add a Z-Wave node to the network","ref":"Grizzly.Inclusions.html#add_node/1","title":"Grizzly.Inclusions.add_node/1","type":"function"},{"doc":"Stop an add node inclusion process","ref":"Grizzly.Inclusions.html#add_node_stop/0","title":"Grizzly.Inclusions.add_node_stop/0","type":"function"},{"doc":"Tell the inclusion process which keys to use during the inclusion processDuring S2 inclusion the node being included with send a DSKAddKeysReport to request which keys it can use to included securely. This function is useful for passing back to the node which keys it is allowed to use and depending on that answer the including node might request more information.","ref":"Grizzly.Inclusions.html#grant_keys/1","title":"Grizzly.Inclusions.grant_keys/1","type":"function"},{"doc":"Check to see if there is an inclusion process running","ref":"Grizzly.Inclusions.html#inclusion_running?/0","title":"Grizzly.Inclusions.inclusion_running?/0","type":"function"},{"doc":"Start the process to remove a Z-Wave node from the network","ref":"Grizzly.Inclusions.html#remove_node/1","title":"Grizzly.Inclusions.remove_node/1","type":"function"},{"doc":"Stop a remove node inclusion process","ref":"Grizzly.Inclusions.html#remove_node_stop/0","title":"Grizzly.Inclusions.remove_node_stop/0","type":"function"},{"doc":"Tell the inclusion process what the input DSK isIf the NodeAddDSKReport's :input_dsk_length is 0 you can just call this function without any arguments:Grizzly.Inclusions.set_input_dsk()If you are doing :s2_authenticated or :s2_access_control the NodeAddDSKReport will probably ask for input DSK length of 2. This means it is expecting a 2 byte (16 bit) number, which is normally a 5 digit pin located somewhere on the node that is being added. After locating the pin and you can pass it as an argument like so:Grizzly.Inclusions.set_input_dsk(12345)","ref":"Grizzly.Inclusions.html#set_input_dsk/1","title":"Grizzly.Inclusions.set_input_dsk/1","type":"function"},{"doc":"Stop the inclusion runner","ref":"Grizzly.Inclusions.html#stop/0","title":"Grizzly.Inclusions.stop/0","type":"function"},{"doc":"","ref":"Grizzly.Inclusions.html#t:opt/0","title":"Grizzly.Inclusions.opt/0","type":"type"},{"doc":"Module for working with the Z-Wave network","ref":"Grizzly.Network.html","title":"Grizzly.Network","type":"module"},{"doc":"Delete a node from the network's provisioning list via the node's DSK","ref":"Grizzly.Network.html#delete_node_provisioning/1","title":"Grizzly.Network.delete_node_provisioning/1","type":"function"},{"doc":"Get a list of node ids from the networkJust because a node id might be in the list does not mean the node is on the network. A device might have been reset or unpaired from the controller with out the controller knowing. However, in most use cases this shouldn't be an issue.","ref":"Grizzly.Network.html#get_node_ids/0","title":"Grizzly.Network.get_node_ids/0","type":"function"},{"doc":"Get the nodes provisioning list information via the node's DSK","ref":"Grizzly.Network.html#get_node_provisioning/1","title":"Grizzly.Network.get_node_provisioning/1","type":"function"},{"doc":"List all the nodes on the provisioning list","ref":"Grizzly.Network.html#list_node_provisionings/1","title":"Grizzly.Network.list_node_provisionings/1","type":"function"},{"doc":"Remove a (presumably) failed node","ref":"Grizzly.Network.html#remove_failed_node/1","title":"Grizzly.Network.remove_failed_node/1","type":"function"},{"doc":"Reset the Z-Wave controllerThis command takes a few seconds to run.","ref":"Grizzly.Network.html#reset_controller/0","title":"Grizzly.Network.reset_controller/0","type":"function"},{"doc":"A node to the network provisioning list","ref":"Grizzly.Network.html#set_node_provisioning/2","title":"Grizzly.Network.set_node_provisioning/2","type":"function"},{"doc":"Functions for working directly with a Z-Wave node","ref":"Grizzly.Node.html","title":"Grizzly.Node","type":"module"},{"doc":"Get a node's dsk.The response to this command is the DSKReport command","ref":"Grizzly.Node.html#get_dsk/3","title":"Grizzly.Node.get_dsk/3","type":"function"},{"doc":"Get the information for a node by its idThe response to this command is the NodeInfoCacheReport command","ref":"Grizzly.Node.html#get_info/1","title":"Grizzly.Node.get_info/1","type":"function"},{"doc":"","ref":"Grizzly.Node.html#get_node_info/1","title":"Grizzly.Node.get_node_info/1","type":"function"},{"doc":"Set lifeline association for the nodeThe lifeline associated is used to report events that happen at the Z-Wave device level back to the Z-Wave controller. For example, if you turn on a light and want to be notified, the device will need to have it's lifeline association set.Opts::controller_id - the idea of the main controller to send lifeline reports to (defaults to 1):extra_node_ids - any extra nodes to set add to the association group","ref":"Grizzly.Node.html#set_lifeline_association/2","title":"Grizzly.Node.set_lifeline_association/2","type":"function"},{"doc":"","ref":"Grizzly.Node.html#t:id/0","title":"Grizzly.Node.id/0","type":"type"},{"doc":"","ref":"Grizzly.Node.html#t:lifeline_opts/0","title":"Grizzly.Node.lifeline_opts/0","type":"type"},{"doc":"Cofiguration params::auto_start - setup runtime when Grizzly application starts:on_ready - a {module, function, args} to call after the runtime seems to be up and running correctly:run_zipgateway_bin - if you run zipgateway outside of Grizzly you can set this to falseExample:config :grizzly, runtime: [ auto_start: true, on_ready: {MyModule, :grizzly_ready, []}, run_zipgateway_bin: true ]You're using Grizzly on a Nerves system, this config is probably what you want:config :grizzly, runtime: [ on_ready: {MyFirmwareProject.ZWave, :ready, []} ]The other defaults should work.","ref":"Grizzly.Runtime.html","title":"Grizzly.Runtime","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Grizzly.Runtime.html#child_spec/1","title":"Grizzly.Runtime.child_spec/1","type":"function"},{"doc":"","ref":"Grizzly.Runtime.html#start_link/1","title":"Grizzly.Runtime.start_link/1","type":"function"},{"doc":"","ref":"Grizzly.Runtime.html#t:opt/0","title":"Grizzly.Runtime.opt/0","type":"type"},{"doc":"Module for Z-Wave protocol specific functionality and information","ref":"Grizzly.ZWave.html","title":"Grizzly.ZWave","type":"module"},{"doc":"","ref":"Grizzly.ZWave.html#from_binary/1","title":"Grizzly.ZWave.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.html#to_binary/1","title":"Grizzly.ZWave.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.html#t:node_id/0","title":"Grizzly.ZWave.node_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.html#t:seq_number/0","title":"Grizzly.ZWave.seq_number/0","type":"type"},{"doc":"Data struct and behaviour for working with Z-Wave commands","ref":"Grizzly.ZWave.Command.html","title":"Grizzly.ZWave.Command","type":"behaviour"},{"doc":"Decode the binary string of command params","ref":"Grizzly.ZWave.Command.html#c:decode_params/1","title":"Grizzly.ZWave.Command.decode_params/1","type":"callback"},{"doc":"","ref":"Grizzly.ZWave.Command.html#encode_params/1","title":"Grizzly.ZWave.Command.encode_params/1","type":"function"},{"doc":"Encode the command parameters","ref":"Grizzly.ZWave.Command.html#c:encode_params/1","title":"Grizzly.ZWave.Command.encode_params/1","type":"callback"},{"doc":"Make a new Command.t() from the params providedParam validation should take place here.","ref":"Grizzly.ZWave.Command.html#c:new/1","title":"Grizzly.ZWave.Command.new/1","type":"callback"},{"doc":"Get the command param value out the params list","ref":"Grizzly.ZWave.Command.html#param/3","title":"Grizzly.ZWave.Command.param/3","type":"function"},{"doc":"Just like param/3 but will raise if the the param is not in the param list","ref":"Grizzly.ZWave.Command.html#param!/2","title":"Grizzly.ZWave.Command.param!/2","type":"function"},{"doc":"Put the param value into the params list, updating pervious value if there is one","ref":"Grizzly.ZWave.Command.html#put_param/3","title":"Grizzly.ZWave.Command.put_param/3","type":"function"},{"doc":"Encode the Command.t() into it's binary representation","ref":"Grizzly.ZWave.Command.html#to_binary/1","title":"Grizzly.ZWave.Command.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Command.html#t:delay_seconds/0","title":"Grizzly.ZWave.Command.delay_seconds/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Command.html#t:params/0","title":"Grizzly.ZWave.Command.params/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Command.html#t:t/0","title":"Grizzly.ZWave.Command.t/0","type":"type"},{"doc":"Behaviour for a command class implementation","ref":"Grizzly.ZWave.CommandClass.html","title":"Grizzly.ZWave.CommandClass","type":"behaviour"},{"doc":"Get the byte for the command class","ref":"Grizzly.ZWave.CommandClass.html#c:byte/0","title":"Grizzly.ZWave.CommandClass.byte/0","type":"callback"},{"doc":"Get the name of the command class","ref":"Grizzly.ZWave.CommandClass.html#c:name/0","title":"Grizzly.ZWave.CommandClass.name/0","type":"callback"},{"doc":"A module that implements this behaviour","ref":"Grizzly.ZWave.CommandClass.html#t:t/0","title":"Grizzly.ZWave.CommandClass.t/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.html","title":"Grizzly.ZWave.CommandClasses","type":"module"},{"doc":"Turn the binary representation that is outlined in the Network-Protocol specs","ref":"Grizzly.ZWave.CommandClasses.html#command_class_list_from_binary/1","title":"Grizzly.ZWave.CommandClasses.command_class_list_from_binary/1","type":"function"},{"doc":"Turn the list of command classes into the binary representation outlined in the Network-Protocol command class specification.TODO: add more details","ref":"Grizzly.ZWave.CommandClasses.html#command_class_list_to_binary/1","title":"Grizzly.ZWave.CommandClasses.command_class_list_to_binary/1","type":"function"},{"doc":"Try to parse the byte into a command class","ref":"Grizzly.ZWave.CommandClasses.html#from_byte/1","title":"Grizzly.ZWave.CommandClasses.from_byte/1","type":"function"},{"doc":"Get the byte representation of the command class","ref":"Grizzly.ZWave.CommandClasses.html#to_byte/1","title":"Grizzly.ZWave.CommandClasses.to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.html#t:command_class/0","title":"Grizzly.ZWave.CommandClasses.command_class/0","type":"type"},{"doc":"Alarm Command Class","ref":"Grizzly.ZWave.CommandClasses.Alarm.html","title":"Grizzly.ZWave.CommandClasses.Alarm","type":"module"},{"doc":"Association Command ClassThis command class provides commands for associating Z-Wave nodes together that are the same network. That means when some event happens on Z-Wave node A it can send messages to another node on the network node B.","ref":"Grizzly.ZWave.CommandClasses.Association.html","title":"Grizzly.ZWave.CommandClasses.Association","type":"module"},{"doc":"&quot;AssociationGroupInfo&quot; Command ClassThis command class allows a node to advertise the capabilities of each association group supported by a given application resource.","ref":"Grizzly.ZWave.CommandClasses.AssociationGroupInfo.html","title":"Grizzly.ZWave.CommandClasses.AssociationGroupInfo","type":"module"},{"doc":"&quot;Basic&quot; Command ClassSupports getting and setting the on/off state of a device","ref":"Grizzly.ZWave.CommandClasses.Basic.html","title":"Grizzly.ZWave.CommandClasses.Basic","type":"module"},{"doc":"&quot;Battery&quot; Command ClassThis command class is used to get the battery level.","ref":"Grizzly.ZWave.CommandClasses.Battery.html","title":"Grizzly.ZWave.CommandClasses.Battery","type":"module"},{"doc":"Configuration command classThis command class is used to configure manufacturer specific configuration parameters","ref":"Grizzly.ZWave.CommandClasses.Configuration.html","title":"Grizzly.ZWave.CommandClasses.Configuration","type":"module"},{"doc":"DoorLock Command ClassThis command class provides commands that are used to operate and configure door lock devices","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html","title":"Grizzly.ZWave.CommandClasses.DoorLock","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#mode_from_byte/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.mode_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#mode_to_byte/1","title":"Grizzly.ZWave.CommandClasses.DoorLock.mode_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.DoorLock.html#t:mode/0","title":"Grizzly.ZWave.CommandClasses.DoorLock.mode/0","type":"type"},{"doc":"The Firmware Update Meta Data Command Class may be used to transfer a firmware image to a Z-Wave device.","ref":"Grizzly.ZWave.CommandClasses.FirmwareUpdateMD.html","title":"Grizzly.ZWave.CommandClasses.FirmwareUpdateMD","type":"module"},{"doc":"ManufacturerSpecific Command ClassThis command class is used to advertise manufacturer information","ref":"Grizzly.ZWave.CommandClasses.ManufacturerSpecific.html","title":"Grizzly.ZWave.CommandClasses.ManufacturerSpecific","type":"module"},{"doc":"&quot;Meter&quot; Command ClassThe Meter Command Class is used to advertise instantaneous and accumulated numerical readings.","ref":"Grizzly.ZWave.CommandClasses.Meter.html","title":"Grizzly.ZWave.CommandClasses.Meter","type":"module"},{"doc":"&quot;MultiChannel&quot; Command ClassThe Multi Channel command class is used to address one or more End Points in a Multi Channel device.","ref":"Grizzly.ZWave.CommandClasses.MultiChannel.html","title":"Grizzly.ZWave.CommandClasses.MultiChannel","type":"module"},{"doc":"Command class for working with Z-Wave network updates and resetting the controller back to the factor defaults","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#add_mode_from_bit/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.add_mode_from_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#add_mode_to_byte/1","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.add_mode_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.html#t:add_mode/0","title":"Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode.add_mode/0","type":"type"},{"doc":"Network Management Inclusion Command ClassThis command class provides the commands for adding and removing Z-Wave nodes to the Z-Wave network","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementInclusion.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementInclusion","type":"module"},{"doc":"Network Management Proxy Command ClassThis command class is used to report information about the Z-Wave nodes on the network such has node ids, supported command classes and their security support, multi channel end points (version 2 only), and basic, generic, and specific device classes.","ref":"Grizzly.ZWave.CommandClasses.NetworkManagementProxy.html","title":"Grizzly.ZWave.CommandClasses.NetworkManagementProxy","type":"module"},{"doc":"&quot;NoOperation&quot; Command ClassSupports the :no_operation command which does nothing other than confirming that the device is responsive.","ref":"Grizzly.ZWave.CommandClasses.NoOperation.html","title":"Grizzly.ZWave.CommandClasses.NoOperation","type":"module"},{"doc":"NodeProvisioning Command ClassThe Node Provisioning command class is used to manage a list of unique nodes, called the &quot;Node Provisioning List&quot;, in SmartStart controller or gateway.","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html#encode_meta_extensions/1","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning.encode_meta_extensions/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html#optional_binary_to_dsk/1","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning.optional_binary_to_dsk/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.NodeProvisioning.html#optional_dsk_to_binary/1","title":"Grizzly.ZWave.CommandClasses.NodeProvisioning.optional_dsk_to_binary/1","type":"function"},{"doc":"Deprecated command class for triggered/not triggered sensors.","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html","title":"Grizzly.ZWave.CommandClasses.SensorBinary","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html#decode_type/1","title":"Grizzly.ZWave.CommandClasses.SensorBinary.decode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html#encode_type/1","title":"Grizzly.ZWave.CommandClasses.SensorBinary.encode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorBinary.html#t:sensor_type/0","title":"Grizzly.ZWave.CommandClasses.SensorBinary.sensor_type/0","type":"type"},{"doc":"&quot;SensorMultilevel&quot; Command ClassThe Multilevel Sensor Command Class is used to advertise numerical sensor readings.","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#decode_sensor_type/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.decode_sensor_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#decode_sensor_types/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.decode_sensor_types/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#encode_sensor_type/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.encode_sensor_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.SensorMultilevel.html#encode_sensor_types/1","title":"Grizzly.ZWave.CommandClasses.SensorMultilevel.encode_sensor_types/1","type":"function"},{"doc":"The Supervision Command Class allows a sending node to request application-level delivery confirmation from a receiving node.","ref":"Grizzly.ZWave.CommandClasses.Supervision.html","title":"Grizzly.ZWave.CommandClasses.Supervision","type":"module"},{"doc":"Switch Binary Command ClassThis command class provides command work with switches that are either on or off.","ref":"Grizzly.ZWave.CommandClasses.SwitchBinary.html","title":"Grizzly.ZWave.CommandClasses.SwitchBinary","type":"module"},{"doc":"Multilevel Switch Command ClassThis command class provides commands that work with multilevel switches.","ref":"Grizzly.ZWave.CommandClasses.SwitchMultilevel.html","title":"Grizzly.ZWave.CommandClasses.SwitchMultilevel","type":"module"},{"doc":"&quot;ThermostatFanMode&quot; Command ClassWhat type of commands does this command class support?","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html#decode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html#encode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.html#t:mode/0","title":"Grizzly.ZWave.CommandClasses.ThermostatFanMode.mode/0","type":"type"},{"doc":"&quot;ThermostatFanState&quot; Command ClassThe Thermostat Fan State Command Class is used to obtain the fan operating state of the thermostat.","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html#decode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState.decode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html#encode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState.encode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatFanState.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.ThermostatFanState.state/0","type":"type"},{"doc":"&quot;ThermostatMode&quot; Command ClassThe Thermostat Mode Command Class is used to control which mode a thermostat operates.","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html","title":"Grizzly.ZWave.CommandClasses.ThermostatMode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html#decode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatMode.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html#encode_mode/1","title":"Grizzly.ZWave.CommandClasses.ThermostatMode.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatMode.html#t:mode/0","title":"Grizzly.ZWave.CommandClasses.ThermostatMode.mode/0","type":"type"},{"doc":"&quot;ThermostatOperatingState&quot; Command ClassThe Thermostat Operating State Command Class is used to obtain the operating state of the thermostat.","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html#decode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.decode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html#encode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.encode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.ThermostatOperatingState.state/0","type":"type"},{"doc":"&quot;ThermostatSetback&quot; Command ClassThe Thermostat Setback Command Class is used to change the current state of a non-schedule setback thermostat.","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#decode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.decode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#decode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.decode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#encode_state/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.encode_state/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#encode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.encode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#t:state/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.state/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetback.html#t:type/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetback.type/0","type":"type"},{"doc":"&quot;ThermostatSetpoint&quot; Command Class The Thermostat Setpoint Command Class is used to configure setpoints for the modes supported by a thermostat.What type of commands does this command class support?","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#decode_scale/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.decode_scale/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#decode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.decode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#encode_scale/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.encode_scale/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#encode_type/1","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.encode_type/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#t:scale/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.scale/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.html#t:type/0","title":"Grizzly.ZWave.CommandClasses.ThermostatSetpoint.type/0","type":"type"},{"doc":"Command Class for working with user codes","ref":"Grizzly.ZWave.CommandClasses.UserCode.html","title":"Grizzly.ZWave.CommandClasses.UserCode","type":"module"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.UserCode.html#user_id_status_from_byte/1","title":"Grizzly.ZWave.CommandClasses.UserCode.user_id_status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.UserCode.html#user_id_status_to_byte/1","title":"Grizzly.ZWave.CommandClasses.UserCode.user_id_status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.CommandClasses.UserCode.html#t:user_id_status/0","title":"Grizzly.ZWave.CommandClasses.UserCode.user_id_status/0","type":"type"},{"doc":"Version Command ClassThis command class is used to get version information about the Z-Wave protocol, command classes, and vendor specific versions","ref":"Grizzly.ZWave.CommandClasses.Version.html","title":"Grizzly.ZWave.CommandClasses.Version","type":"module"},{"doc":"&quot;WakeUp&quot; Command ClassThis command class is used to get and set the wake-up intervals of wake-up devices.","ref":"Grizzly.ZWave.CommandClasses.WakeUp.html","title":"Grizzly.ZWave.CommandClasses.WakeUp","type":"module"},{"doc":"ZIP Command ClassThe Z/IP command class is useful for encapsulating Z-Wave commands to be sent via IP.","ref":"Grizzly.ZWave.CommandClasses.ZIP.html","title":"Grizzly.ZWave.CommandClasses.ZIP","type":"module"},{"doc":"This command notifies the application of the alarm stateParams::type - the specific alarm type being reported - this different for each application, see device user manual for more details (required):level - the level is device specific, see device user manual for more details (required):zensor_net_node_id - the Zensor net node, if the device is not based off of Zensor Net, then this field is 0 (v2, optional, default 0):zwave_status - if the device status is active or deactive (v2):zwave_type - part of Grizzly.ZWave.Notifications spec (v2):zwave_event - part of the Grizzly.ZWave.Notifications spec (v2):event_parameters - additional parameters for the event, see user manual for more information (v2, optional, default [])","ref":"Grizzly.ZWave.Commands.AlarmReport.html","title":"Grizzly.ZWave.Commands.AlarmReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AlarmReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AlarmReport.param/0","type":"type"},{"doc":"Get the current destinations for the association groupThis should be respond to with a Grizzly.ZWave.Commands.AssociationReportParams::grouping_identifier - the group to request a report about (required)","ref":"Grizzly.ZWave.Commands.AssociationGet.html","title":"Grizzly.ZWave.Commands.AssociationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGet.param/0","type":"type"},{"doc":"This command is used to request the commands that are sent via a given association group.Params::allow_cache - This field indicates that a Z-Wave Gateway device is allowed to intercept the request and return a cached response on behalf of the specified target. (required):group_id - The group identifier (required)","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListGet.param/0","type":"type"},{"doc":"This command is used to advertise the commands that are sent via an actual association group.Params::group_id - the group identifier:commands - lists of commands","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupCommandListReport.param/0","type":"type"},{"doc":"This command is used to request the properties of one or more association group.Params::refresh_cache - Whether to refresh cached info:all - Get info on all assocation groups:group_id - get info on this association group (required if all is false)","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupInfoGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupInfoGet.param/0","type":"type"},{"doc":"This command is used to advertise the properties of one or more association groups.Params::dynamic - whether the group info is subject to be changed by the device:groups_info - a list of group info","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupInfoReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.html#t:group_info/0","title":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.group_info/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupInfoReport.param/0","type":"type"},{"doc":"This command is used to query the name of an association group.Params::group_id - the group identifier","ref":"Grizzly.ZWave.Commands.AssociationGroupNameGet.html","title":"Grizzly.ZWave.Commands.AssociationGroupNameGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupNameGet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupNameGet.param/0","type":"type"},{"doc":"This command is used to advertise the assigned name of an association group.Params::group_id - the group id:name - the group's name","ref":"Grizzly.ZWave.Commands.AssociationGroupNameReport.html","title":"Grizzly.ZWave.Commands.AssociationGroupNameReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationGroupNameReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationGroupNameReport.param/0","type":"type"},{"doc":"Report the destinations for the given association groupParams::grouping_identifier - the grouping identifier for the the association group (required):max_nodes_supported - the max number of destinations for the association group (required):reports_to_follow - if the full destination list is too long for one report this field reports the number of follow up reports (optional default 0):nodes - the destination nodes in the association group (required)","ref":"Grizzly.ZWave.Commands.AssociationReport.html","title":"Grizzly.ZWave.Commands.AssociationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationReport.param/0","type":"type"},{"doc":"Module for the ASSOCIATION_SET commandThe node receiving this command should add the specified node ids to the association group. However, if the association group for the node is full this command is ignored.Params::grouping_identifier - the association grouping identifier (required):nodes - list of nodes to add the grouping identifier (required)","ref":"Grizzly.ZWave.Commands.AssociationSet.html","title":"Grizzly.ZWave.Commands.AssociationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.AssociationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.AssociationSet.param/0","type":"type"},{"doc":"This module implements the BASIC_GET command form the COMMAND_CLASS_BASIC command classParams: - none","ref":"Grizzly.ZWave.Commands.BasicGet.html","title":"Grizzly.ZWave.Commands.BasicGet","type":"module"},{"doc":"This module implements the BASIC_REPORT command of the COMMAND_CLASS_BASIC command classParams::value - the current value (:on or :off or :unknown):target_value - the target value (:on or :off or :unknown) - v2:duration - the time in seconds needed to reach the Target Value at the actual transition rate - v2","ref":"Grizzly.ZWave.Commands.BasicReport.html","title":"Grizzly.ZWave.Commands.BasicReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicReport.html#t:duration/0","title":"Grizzly.ZWave.Commands.BasicReport.duration/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicReport.html#t:param/0","title":"Grizzly.ZWave.Commands.BasicReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicReport.html#t:value/0","title":"Grizzly.ZWave.Commands.BasicReport.value/0","type":"type"},{"doc":"This module implements the BASIC_SET command of the COMMAND_CLASS_BASIC command classParams::value - :on or :off","ref":"Grizzly.ZWave.Commands.BasicSet.html","title":"Grizzly.ZWave.Commands.BasicSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.BasicSet.html#t:param/0","title":"Grizzly.ZWave.Commands.BasicSet.param/0","type":"type"},{"doc":"This module implements the BATTERY_GET command in the COMMAND_CLASS_BATTERY command class.Params: - none -","ref":"Grizzly.ZWave.Commands.BatteryGet.html","title":"Grizzly.ZWave.Commands.BatteryGet","type":"module"},{"doc":"This module implements the BATTERY_REPORT command of the COMMAND_CLASS_BATTERY command class.Params::level - percent charged - v1:charging_status - whether charging, discharging or maintaining - v2:rechargeable - whether the battery is rechargeable - v2:backup - whether used as a backup source of power - v2:overheating - whether it is overheating - v2:low_fluid - whether the battery fluid is low and should be refilled - v2:replace_recharge - whether the battery needs to be replaced or recharged- v2:disconnected - whether the battery is disconnected nd the node is running on an alternative power source - v2:low_temperature - whether the battery of a device has stopped charging due to low temperature - v3","ref":"Grizzly.ZWave.Commands.BatteryReport.html","title":"Grizzly.ZWave.Commands.BatteryReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.BatteryReport.html#t:param/0","title":"Grizzly.ZWave.Commands.BatteryReport.param/0","type":"type"},{"doc":"This module implements command VERSION_COMMAND_CLASS_GET of command class COMMAND_CLASS_VERSIONParams::command_class - the atom name of a command class (required)","ref":"Grizzly.ZWave.Commands.CommandClassGet.html","title":"Grizzly.ZWave.Commands.CommandClassGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.CommandClassGet.html#t:param/0","title":"Grizzly.ZWave.Commands.CommandClassGet.param/0","type":"type"},{"doc":"Reports the command class version for a deviceParams::command_class - the name of the command class the report is for (required):version - the version of the command class in the report (required)","ref":"Grizzly.ZWave.Commands.CommandClassReport.html","title":"Grizzly.ZWave.Commands.CommandClassReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.CommandClassReport.html#t:param/0","title":"Grizzly.ZWave.Commands.CommandClassReport.param/0","type":"type"},{"doc":"This command is used to query the value of a configuration parameter.Params::param_number - the requested configuration parameter","ref":"Grizzly.ZWave.Commands.ConfigurationGet.html","title":"Grizzly.ZWave.Commands.ConfigurationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationGet.param/0","type":"type"},{"doc":"Reports on a configuration parameterParams::size - specifies the size of the configuration parameter (required):value - the value of the parameter (required):param_number - the configuration parameter number reported on (required)SizeThe size of the parameter are the values 1, 2, and 4 which is the number of bytes for the configuration parameter value. This should be provided by the user manual of our device.","ref":"Grizzly.ZWave.Commands.ConfigurationReport.html","title":"Grizzly.ZWave.Commands.ConfigurationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationReport.param/0","type":"type"},{"doc":"Set the configuration parameterParams::size - specifies the size of the configuration parameter (required if not resetting to default):value - the value of the parameter, can be set to :default to set the parameter back to the factory default value (required):param_number - the configuration parameter number to set (required)SizeThe size of the parameter are the values 1, 2, and 4 which is the number of bytes for the configuration parameter value. This should be provided by the user manual of our device.Factory reset a paramIf you want to factory reset a configuration parameter you can pass :default as the :value param","ref":"Grizzly.ZWave.Commands.ConfigurationSet.html","title":"Grizzly.ZWave.Commands.ConfigurationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ConfigurationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ConfigurationSet.param/0","type":"type"},{"doc":"Request the S2 DSK of a NodeThe response to this command is DSKReportParams::seq_number - the sequence number of the networked command (required):add_mode - some S2 nodes maybe have two different types of DSKs one being added into a Z-Wave network (learn mode) and another for adding other nodes in the network (add mode) (optional default :learn)","ref":"Grizzly.ZWave.Commands.DSKGet.html","title":"Grizzly.ZWave.Commands.DSKGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DSKGet.html#t:param/0","title":"Grizzly.ZWave.Commands.DSKGet.param/0","type":"type"},{"doc":"Report the DSK for the Z-Wave NodeThis command is the response to the Grizzly.ZWave.Commands.DSKGet commandParams::seq_number - the sequence number for the networked command (required):add_mode - the add mode for the DSK see Grizzly.ZWave.CommandClasses.NetworkManagementBasicNode for more information (required):dsk - the DSK string for the node, see Grizzly.ZWave.DSK for more information (required)","ref":"Grizzly.ZWave.Commands.DSKReport.html","title":"Grizzly.ZWave.Commands.DSKReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DSKReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DSKReport.param/0","type":"type"},{"doc":"Reset a Node Z-Wave node back to factory default stateThe response to this command should be the Grizzly.ZWave.Commands.DefaultSetComplete command.Params::seq_number - the sequence number of the networked command (required)","ref":"Grizzly.ZWave.Commands.DefaultSet.html","title":"Grizzly.ZWave.Commands.DefaultSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSet.html#t:param/0","title":"Grizzly.ZWave.Commands.DefaultSet.param/0","type":"type"},{"doc":"Command to indicate the result of a Grizzly.ZWave.Commands.DefaultSet operationParams::seq_number - the sequence number of the networked command (required):status - the status of the default set operation (required)","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html","title":"Grizzly.ZWave.Commands.DefaultSetComplete","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#status_from_byte/1","title":"Grizzly.ZWave.Commands.DefaultSetComplete.status_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#status_to_byte/1","title":"Grizzly.ZWave.Commands.DefaultSetComplete.status_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#t:param/0","title":"Grizzly.ZWave.Commands.DefaultSetComplete.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DefaultSetComplete.html#t:status/0","title":"Grizzly.ZWave.Commands.DefaultSetComplete.status/0","type":"type"},{"doc":"OperationGet request the door lock operating modeThe response to this command should be Grizzly.ZWave.Commands.OperationReportParams: - none -","ref":"Grizzly.ZWave.Commands.DoorLockOperationGet.html","title":"Grizzly.ZWave.Commands.DoorLockOperationGet","type":"module"},{"doc":"OperationReport is used to advertise the status of a door lockThis is response to the Grizzly.ZWave.Commands.OperationGet command.Params::mode - the door operating lock mode (required):outside_handles_mode - a map of the outside door handles and if they can or cannot open the door locally (optional):inside_handles_mode - a map of the inside door handles and if they can or cannot open the door locally (optional):latch_position - the position of the latch (optional):bolt_position - the position of the bolt (optional):door_state - the state of the door being open or closed (optional):timeout_minutes - how long the door has been unlocked (required):timeout_seconds - how long the door has been unlocked (required):target_mode - the target mode of an ongoing transition or of the most recent transition (optional - v4)duration - the estimated remaining time before the target mode is realized (optional - v4)","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html","title":"Grizzly.ZWave.Commands.DoorLockOperationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#door_condition_to_byte/3","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.door_condition_to_byte/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#door_handles_modes_to_byte/1","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.door_handles_modes_to_byte/1","type":"function"},{"doc":"This param only matters if the door lock says it supports this door component in the CapabilitiesReport.If it isn't support the node receiving this report can ignore.For defaults, if this param isn't provided during when calling new/1, we 0 this field out by setting it to :disabled","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:bolt_position/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.bolt_position/0","type":"type"},{"doc":"This param only matters if the door lock says it supports this door component in the CapabilitiesReport.If it isn't support the node receiving this report can ignore.For defaults, if this param isn't provided during when calling new/1, we 0 this field out by setting it to :disabled","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:door_state/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.door_state/0","type":"type"},{"doc":"These modes tell if the handle can open the door locally or not.The door lock does not have to report all or any of these, so the default is to set them all to disabled if they are not specified when building the command.","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:handles_mode/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.handles_mode/0","type":"type"},{"doc":"This param only matters if the door lock says it supports this door component in the CapabilitiesReport.If it isn't support the node receiving this report can ignore.For defaults, if this param isn't provided during when calling new/1, we 0 this field out by setting it to :disabled","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:latch_position/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.latch_position/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:timeout_minutes/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.timeout_minutes/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationReport.html#t:timeout_seconds/0","title":"Grizzly.ZWave.Commands.DoorLockOperationReport.timeout_seconds/0","type":"type"},{"doc":"OperationSet command allows you to lock or unlock lock devicesParams::mode - the mode of the operation of the lock device","ref":"Grizzly.ZWave.Commands.DoorLockOperationSet.html","title":"Grizzly.ZWave.Commands.DoorLockOperationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.DoorLockOperationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.DoorLockOperationSet.param/0","type":"type"},{"doc":"This command is used to remove a non-responding node. It will only succeed if the controller has already put the node on the failed nodes list.Params::seq_number - the sequence number of the networked command (required):node_id - The id of the node to be removed if failed as presumed (required)","ref":"Grizzly.ZWave.Commands.FailedNodeRemove.html","title":"Grizzly.ZWave.Commands.FailedNodeRemove","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeRemove.html#t:param/0","title":"Grizzly.ZWave.Commands.FailedNodeRemove.param/0","type":"type"},{"doc":"This command reports on the attempted removal of a presumed failed node.Params::node_id - the id of the node which removal for failure was attempted:seq_number - the sequence number of the removal command:status - whether the presumed failed node was removed","ref":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.html","title":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.html#t:param/0","title":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.FailedNodeRemoveStatus.status/0","type":"type"},{"doc":"This module implements command FIRMWARE_MD_GET of command class COMMAND_CLASS_FIRMWARE_UPDATE_MD The command requests a FIRMWARE_MD_REPORTParams: -none-","ref":"Grizzly.ZWave.Commands.FirmwareMDGet.html","title":"Grizzly.ZWave.Commands.FirmwareMDGet","type":"module"},{"doc":"The Firmware Meta Data Report Command is used to advertise the status of the current firmware in the device.Params::manufacturer_id - A unique ID identifying the manufacturer of the device:firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant.:checksum - The checksum of the firmware image.:upgradable? - Whether the Z-Wave chip is firmware upgradable:max_fragment_size - The maximum number of Data bytes that a device is able to receive at a time:other_firmware_ids - Ids of firmware targets other than the Z-Wave chip. Empty list if the device's only firmware target is the Z-Wave chip:hardware_version - A value which is unique to this particular version of the product:activation_supported? - Whether the node supports subsequent activation after Firmware Update transfer:active_during_transfer? - Whether the supporting node’s Command Classes functionality will continue to function normally during Firmware Update transfer.","ref":"Grizzly.ZWave.Commands.FirmwareMDReport.html","title":"Grizzly.ZWave.Commands.FirmwareMDReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareMDReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareMDReport.param/0","type":"type"},{"doc":"This command is used to advertise the result of a firmware update operation initiated by the Firmware Update Activation Set Command.Params:status - The status of activating the updated firmware:manufacturer_id - A unique ID identifying the manufacturer of the device (required):firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant. (required):checksum - The checksum of the firmware image. (required):firmware_target - The firmware image to be updated - 0x00 for the ZWave chip, others are defined by the manufacturer (required):hardware_version - The hardware version (version 5)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.html#t:status/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationReport.status/0","type":"type"},{"doc":"This command is used to initiate the programming of a previously transferred firmware image.Params::manufacturer_id - A unique ID identifying the manufacturer of the device (required):firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant. (required):checksum - The checksum of the firmware image. (required):firmware_target - The firmware image to be updated - 0x00 for the ZWave chip, others are defined by the manufacturer (required):hardware_version - The hardware version (version 5)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateActivationSet.param/0","type":"type"},{"doc":"The Firmware Update Meta Data Get Command is used to request one or more Firmware Update Meta Data Report Commands.Params::number_of_reports - Number of firmware update md reports to be received in response to this command (required):report_number - The requested report (required)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDGet.param/0","type":"type"},{"doc":"The Firmware Update Meta Data Report Command is used to transfer a firmware image fragment.Params::last? - whether this report carries the last firmware image fragment. (required):report_number - indicates the sequence number of the contained firmware fragment (required):data - one firmware image fragment (required):checksum - the checksum for the entire command (minus the checksum bytes) (v3 - optional)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDReport.param/0","type":"type"},{"doc":"The Firmware Update Meta Data Request Get Command is used to request that a firmware update be initiated.Params::manufacturer_id - A unique ID identifying the manufacturer of the device (required):firmware_id - A manufacturer SHOULD assign a unique Firmware ID to each existing product variant. (required):checksum - The checksum of the firmware image. (required):firmware_target - The firmware image to be updated - 0x00 for the ZWave chip, others are defined by the manufacturer (v3):fragment_size - The requested number of Data bytes that is to be used for firmware fragments (v3):activation_may_be_delayed? - Whether the receiving node may delay the actual firmware update. (V4):hardware_version - A value which is unique to this particular version of the product. (v5+)","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGet.param/0","type":"type"},{"doc":"This command is used to advertise if the firmware update will be initiated.Params::status - the status of the firmware update request, either :ok or an error such as :invalid_manufacturer_or_device_id","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#encode_status/1","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.html#t:status/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReport.status/0","type":"type"},{"doc":"This command is used to advertise the firmware update status.Params::status the status of the firmware update:wait_time - the time in seconds that is needed before the receiving node again becomes available","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.html","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.html#t:param/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.html#t:status/0","title":"Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReport.status/0","type":"type"},{"doc":"Module for the DEVICE_SPECIFIC_GET command of command class COMMAND_CLASS_MANUFACTURER_SPECIFICParams:device_id_type - :oem_factory_default_device_id_type or :serial_number or :pseudo_random (required)","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.html#t:device_id_type/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.device_id_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificGet.param/0","type":"type"},{"doc":"Module for the DEVICE_SPECIFIC_REPORT command of command class COMMAND_CLASS_MANUFACTURER_SPECIFIC Report the manufacturer specific device specific informationParams::device_id_type - the type of device id reported (required):device_id - unique ID for the device id type (required)","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html#t:device_id/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.device_id/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html#t:device_id_type/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.device_id_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificDeviceSpecificReport.param/0","type":"type"},{"doc":"Module for the MANUFACTURER_SPECIFIC_GET command of command class COMMAND_CLASS_MANUFACTURER_SPECIFICParams: - none -","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificGet.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificGet","type":"module"},{"doc":"Module for the MANUFACTURER_SPECIFIC_REPORT command of command class COMMAND_CLASS_MANUFACTURER_SPECIFIC Report the manufacturer specific informationParams::manufacturer_id - unique ID for the manufacturer (required):product_type_id - unique ID for the product type (required):prodcut_id - unique ID for the actual product (required)","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificReport.html","title":"Grizzly.ZWave.Commands.ManufacturerSpecificReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ManufacturerSpecificReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ManufacturerSpecificReport.param/0","type":"type"},{"doc":"This module implements the METER_GET command of the COMMAND_CLASS_METER command class.This command is used to request the current meter reading to a supporting node.Params: - none - (v1)","ref":"Grizzly.ZWave.Commands.MeterGet.html","title":"Grizzly.ZWave.Commands.MeterGet","type":"module"},{"doc":"This module implements the command METER_REPORT of the COMMAND_CLASS_METER command class.This command is used to advertise the current meter reading at the sending node.Params::meter_type - the type of metering physical unit being reported (required):scale - the unit used (required):value - the value being reported (required)","ref":"Grizzly.ZWave.Commands.MeterReport.html","title":"Grizzly.ZWave.Commands.MeterReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MeterReport.html#t:meter_scale/0","title":"Grizzly.ZWave.Commands.MeterReport.meter_scale/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.MeterReport.html#t:meter_type/0","title":"Grizzly.ZWave.Commands.MeterReport.meter_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.MeterReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MeterReport.param/0","type":"type"},{"doc":"This command is used to query the number of End Points implemented by the receiving node.Params: - none","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointGet.html","title":"Grizzly.ZWave.Commands.MultiChannelEndpointGet","type":"module"},{"doc":"This command is used to advertise the number of End Points implemented by the sending node.Params::dynamic - whether the node implements a dynamic number of End Points (required):identical - whether all end points have identical capabilities (required):endpoints - the number of endpoints (required):aggregated_endpoints - the number of Aggregated End Points implemented by this node (optional - v4)","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointReport.html","title":"Grizzly.ZWave.Commands.MultiChannelEndpointReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.MultiChannelEndpointReport.html#t:param/0","title":"Grizzly.ZWave.Commands.MultiChannelEndpointReport.param/0","type":"type"},{"doc":"This commands does nothing other than test if the node is respondingParams: - none -","ref":"Grizzly.ZWave.Commands.NoOperation.html","title":"Grizzly.ZWave.Commands.NoOperation","type":"module"},{"doc":"Command for NODE_ADDParams::seq_number - the sequence number for the network command (required):mode - the inclusion mode (optional default :node_add_any_s2):tx_opts - the transmission options (optional default :explore)If your controller does not support the NETWORK_MANAGEMENT_INCLUSION version 2, you will ned to pass :node_add_any as the :mode parameter.This command should return the NodeAddStatus report after inclusion is complete","ref":"Grizzly.ZWave.Commands.NodeAdd.html","title":"Grizzly.ZWave.Commands.NodeAdd","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#decode_mode/1","title":"Grizzly.ZWave.Commands.NodeAdd.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#decode_tx_opt/1","title":"Grizzly.ZWave.Commands.NodeAdd.decode_tx_opt/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#encode_mode/1","title":"Grizzly.ZWave.Commands.NodeAdd.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#encode_tx_opt/1","title":"Grizzly.ZWave.Commands.NodeAdd.encode_tx_opt/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#t:mode/0","title":"Grizzly.ZWave.Commands.NodeAdd.mode/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAdd.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAdd.html#t:tx_opt/0","title":"Grizzly.ZWave.Commands.NodeAdd.tx_opt/0","type":"type"},{"doc":"The Z-Wave Command NODE_ADD_DSK_REPORTThis report is used by the including controller to ask for the DSK for the device that is being included.Params:seq_number - sequence number for the command (required):input_dsk_length - the required number of bytes must be in the :dsk field to be authenticated (optional default: 0):dsk - the DSK for the device see Grizzly.ZWave.DSK for more information (required)The :input_dsk_length field can be set to 0 if not provided. That means that device does not require any user input to the DSK set command to authenticate the device. This case is normal when :s2_unauthenticated or client side authentication has been given.","ref":"Grizzly.ZWave.Commands.NodeAddDSKReport.html","title":"Grizzly.ZWave.Commands.NodeAddDSKReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddDSKReport.html#validate_and_ensure_input_dsk_length/1","title":"Grizzly.ZWave.Commands.NodeAddDSKReport.validate_and_ensure_input_dsk_length/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddDSKReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAddDSKReport.param/0","type":"type"},{"doc":"Command to set the DSK for a including nodeParams::seq_number - the sequence number for the command (required):accept - the including controller accepts the inclusion process and should proceed with adding the including node (required)input_dsk_length - the length of the DSK provided (required)input_dsk - the DSK pin for the including node (required)","ref":"Grizzly.ZWave.Commands.NodeAddDSKSet.html","title":"Grizzly.ZWave.Commands.NodeAddDSKSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddDSKSet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAddDSKSet.param/0","type":"type"},{"doc":"Command to report the security keys requested by an including node if that node is participating in S2 bootstrapping.Params::seq_number - the sequence number of the command (required):csa - if the including node is doing client side authentication (require):requested_keys - a list of requested security keys see Grizzly.ZWave.Security for more information. (required)","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html","title":"Grizzly.ZWave.Commands.NodeAddKeysReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#decode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.decode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#decode_requested_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.decode_requested_keys/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#encode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.encode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysReport.html#encode_requested_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysReport.encode_requested_keys/1","type":"function"},{"doc":"Command used to grant the security keys to the including node if the including node requested keys.This normally only needs to happen during the S2 bootstrapping process.Params::seq_number - the sequence number (required):csa - if the including node requested client side authentication, then setting this to true will allow for that node to preform CSA (required):granted_keys - the keys the including controller is granting to the including device, see Grizzly.ZWave.Security for more information (required)","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html","title":"Grizzly.ZWave.Commands.NodeAddKeysSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#decode_accepted/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.decode_accepted/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#decode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.decode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#decode_granted_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.decode_granted_keys/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#encode_accepted/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.encode_accepted/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#encode_csa/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.encode_csa/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddKeysSet.html#encode_granted_keys/1","title":"Grizzly.ZWave.Commands.NodeAddKeysSet.encode_granted_keys/1","type":"function"},{"doc":"Command for NODE_ADD_STATUSThis command is normally the report from adding a node to the Z-Wave networkParams::seq_number - the sequence number of the inclusion command:status - the status of the inclusion:node_id - the new id of the new Z-Wave node:listening? - if the node is a listening node or not:basic_device_class - the Z-Wave basic device class:generic_device_class - the Z-Wave generic device class:specific_device_class - the Z-Wave specific device class:command_classes - a list of the command class the device supports, tagged by their security level used only if the device was included securely:granted_keys - the security keys granted during S2 inclusion (optional):kex_fail_type - the error that occurred in the S2 bootstrapping (optional)","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html","title":"Grizzly.ZWave.Commands.NodeAddStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeAddStatus.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#encode_listening_bit/1","title":"Grizzly.ZWave.Commands.NodeAddStatus.encode_listening_bit/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeAddStatus.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeAddStatus.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.NodeAddStatus.status/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeAddStatus.html#t:tagged_command_classes/0","title":"Grizzly.ZWave.Commands.NodeAddStatus.tagged_command_classes/0","type":"type"},{"doc":"Report the cached node informationThis command is normally used to respond to the NodeInfoCacheGet commandParams::seq_number - the sequence number of the network command, normally from from the NodeInfoCacheGet command (required):status - the status fo the node information (required):age - the age of the cache data. A number that is expressed 2 ^ n minutes (required):listening? - if the node is listening node or sleeping node (required):command_classes - a list of lists of command classes tagged by security attributes (optional default empty list):basic_device_class - the basic device class (required):generic_device_class - the generic device class (required):specific_device_class - the specific device class (required)","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#bit_to_bool/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.bit_to_bool/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#decode_command_classes/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.decode_command_classes/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_command_classes/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_command_classes/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_listening?/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_listening?/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_optional_functionality_byte/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_optional_functionality_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.param/0","type":"type"},{"doc":"The status of the refresh of the node information cacheStatus::ok - the requested node id could found and up-to-date information is returned:not_responding - the requested node id could be found but fresh information could not be retrieved:unknown - the node id is unknown","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#t:status/0","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.status/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCacheReport.html#t:tagged_command_classes/0","title":"Grizzly.ZWave.Commands.NodeInfoCacheReport.tagged_command_classes/0","type":"type"},{"doc":"Get the node information that is cached on another deviceThis is useful for getting the command classes and device classesWhen sending this command the Z-Wave network should send back a NodeInfoCachedReport command.Params: :seq_number - the sequence number for the networked command (required) :max_age - the max age of the node info frame give in 2^n minutes see section on cached minutes below for more information (optional) :node_id - the node id that that node information is being requested for (required)Cached MinutesThis Z-Wave network will cache node information to perverse bandwidth and provides access to node information about sleeping nodes.When sending the NodeInfoCachedGet command we can specify the max age of the cached data. If the cached data is older than the :max_age param the Z-Wave network will try to refresh the cache and send back the most updated information.The values for the :max_age parameter are numbers from 1 to 14. This number will be 2 ^ number minutes. So if you pass the number 4 the receiving Z-Wave device will consider that 16 minutes.Two other options are :infinite and :force_update. Where :infinite means that the cache will not be freshed regardless of how old the data is and where :force_update means that no matter the age of the cached node data the cache will attempt to be updated.We default to 10 which 1024 minutes, or just a little over 1 day. This default is chosen to limit bandwidth usage. Also, the data found in the report is fairly static, so there isn't a pressing need to update the cache to often.","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#decode_max_age/1","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.decode_max_age/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#encode_max_age/1","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.encode_max_age/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#t:max_age/0","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.max_age/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeInfoCachedGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeInfoCachedGet.param/0","type":"type"},{"doc":"Module for the NODE_LIST_GET commandParams::seq_number - the sequence number for the command (required)","ref":"Grizzly.ZWave.Commands.NodeListGet.html","title":"Grizzly.ZWave.Commands.NodeListGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeListGet.param/0","type":"type"},{"doc":"The NODE_LIST_REPORT command","ref":"Grizzly.ZWave.Commands.NodeListReport.html","title":"Grizzly.ZWave.Commands.NodeListReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#decode_controller_id/1","title":"Grizzly.ZWave.Commands.NodeListReport.decode_controller_id/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#decode_node_ids/1","title":"Grizzly.ZWave.Commands.NodeListReport.decode_node_ids/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeListReport.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#encode_controller_id/1","title":"Grizzly.ZWave.Commands.NodeListReport.encode_controller_id/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#encode_node_ids/1","title":"Grizzly.ZWave.Commands.NodeListReport.encode_node_ids/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeListReport.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeListReport.encode_status/1","type":"function"},{"doc":"Node Provisioning Delete CommandThis command is useful for deleting Z-Wave nodes from the node provisioning list.After deleting a Z-Wave node entry from the node provisioning list you will still have run excluded the node from the Z-Wave network.Params::seq_number - the sequence number for the network command (required):dsk - the DSK string of the node to delete, please see Grizzly.ZWave.DSK for more information (required)","ref":"Grizzly.ZWave.Commands.NodeProvisioningDelete.html","title":"Grizzly.ZWave.Commands.NodeProvisioningDelete","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningDelete.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningDelete.param/0","type":"type"},{"doc":"This module implements command COMMAND_NODE_PROVISIONING_GET of the COMMAND_CLASS_NODE_PROVISIONING command classThis command is used to request the metadata information associated to an entry in the node Provisioning ListParams::seq_number - the sequence number of the networked command (required):dsk - the DSK for the entry being requested (required)","ref":"Grizzly.ZWave.Commands.NodeProvisioningGet.html","title":"Grizzly.ZWave.Commands.NodeProvisioningGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningGet.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_LIST_ITERATION_GET commandThis command is used to read the entire the provisioning list.Params::seq_number - the network command sequence number (required):remaining_counter - indicates the remaining amount of entries in the Provisioning List, not provided if starting (optional)","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet.html","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationGet.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_LIST_ITERATION_REPORT commandThis command is used to advertise the contents of an entry in the Provisioning List of the sending node.Params::seq_number - the network command sequence number (required):remaining_count - indicates the remaining amount of entries in the Provisioning List:dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (optional):meta_extensions - a list of Grizzly.ZWave.SmartStart.MetaExtension.t() (optional default [])","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport.html","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningListIterationReport.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_REPORT commandThis command is used to advertise the contents of an entry in the node Provisioning List of the sending nodeParams::seq_number - the network command sequence number (required):dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (optional):meta_extensions - a list of Grizzly.ZWave.SmartStart.MetaExtension.t() (optional default [])","ref":"Grizzly.ZWave.Commands.NodeProvisioningReport.html","title":"Grizzly.ZWave.Commands.NodeProvisioningReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningReport.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningReport.param/0","type":"type"},{"doc":"Module for working with the NODE_PROVISIONING_SET commandThis command adds a node to the node provisioning list.Params::seq_number - the network command sequence number (required):dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (required):meta_extensions - a list of Grizzly.ZWave.SmartStart.MetaExtension.t() (optional default [])","ref":"Grizzly.ZWave.Commands.NodeProvisioningSet.html","title":"Grizzly.ZWave.Commands.NodeProvisioningSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeProvisioningSet.html#t:param/0","title":"Grizzly.ZWave.Commands.NodeProvisioningSet.param/0","type":"type"},{"doc":"Z-Wave command NODE_REMOVEThis command is useful for removing Z-Wave devices from the Z-Wave networkThis response to this command should be a Grizzly.ZWave.Commands.NodeRemoveStatusParams::seq_number - the sequence number for the network command (required):mode - the mode for the remove node process (optional default :remove_node_any)","ref":"Grizzly.ZWave.Commands.NodeRemove.html","title":"Grizzly.ZWave.Commands.NodeRemove","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemove.html#decode_mode/1","title":"Grizzly.ZWave.Commands.NodeRemove.decode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemove.html#encode_mode/1","title":"Grizzly.ZWave.Commands.NodeRemove.encode_mode/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemove.html#t:mode/0","title":"Grizzly.ZWave.Commands.NodeRemove.mode/0","type":"type"},{"doc":"Z-Wave command for NODE_REMOVE_STATUSThis command is useful to respond to a Grizzly.ZWave.Commands.NodeRemove command.Params::seq_number - the sequence number from the original node remove command:status - the status of the result of the node removal:node_id the node id of the removed nodeAll the parameters are required","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html","title":"Grizzly.ZWave.Commands.NodeRemoveStatus","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html#decode_status/1","title":"Grizzly.ZWave.Commands.NodeRemoveStatus.decode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html#encode_status/1","title":"Grizzly.ZWave.Commands.NodeRemoveStatus.encode_status/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.NodeRemoveStatus.html#t:status/0","title":"Grizzly.ZWave.Commands.NodeRemoveStatus.status/0","type":"type"},{"doc":"What does this command do??Params:sensor_type - the type of sensor (required) one of :general_purpose | :smoke | :co | :co2 | :heat | :water | :freeze | :tamper | :aux | :door_window | :tilt | :motion | :glass_break","ref":"Grizzly.ZWave.Commands.SensorBinaryGet.html","title":"Grizzly.ZWave.Commands.SensorBinaryGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorBinaryGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorBinaryGet.param/0","type":"type"},{"doc":"This command is used to advertise whether a binary sensor was triggered.Params::triggered - whether the sensor is triggered (required):sensor_type - the type of sensor (optional)","ref":"Grizzly.ZWave.Commands.SensorBinaryReport.html","title":"Grizzly.ZWave.Commands.SensorBinaryReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorBinaryReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorBinaryReport.param/0","type":"type"},{"doc":"This module implements command SENSOR_MULTILEVEL_GET of command class COMMAND_CLASS_SENSOR_MULTILEVEL. The command is used to request the current reading from a multilevel sensor.Params: * :sensor_type - one of :temperature or :illuminance or :power or :humidity etc.(v5) * `:scale` - ` 0..3 - identifies a unit of measurement` (v5)","ref":"Grizzly.ZWave.Commands.SensorMultilevelGet.html","title":"Grizzly.ZWave.Commands.SensorMultilevelGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorMultilevelGet.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelGet.html#t:sensor_type/0","title":"Grizzly.ZWave.Commands.SensorMultilevelGet.sensor_type/0","type":"type"},{"doc":"This module implements command COMMAND_CLASS_SENSOR_MULTILEVEL implements the SENSOR_MULTILEVEL_REPORT command class.This command is used to advertise a multilevel sensor reading.Params::sensor_type - one of :temperature, :illuminance, :power, or :humidity etc.(required):scale - 0..3 - identifies a unit of measurement (required):value - the sensed, numerical value (required)","ref":"Grizzly.ZWave.Commands.SensorMultilevelReport.html","title":"Grizzly.ZWave.Commands.SensorMultilevelReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorMultilevelReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelReport.html#t:sensor_type/0","title":"Grizzly.ZWave.Commands.SensorMultilevelReport.sensor_type/0","type":"type"},{"doc":"This module implements command SENSOR_MULTILEVEL_SUPPORTED_GET_SENSOR of command class COMMAND_CLASS_SENSOR_MULTILEVEL The command requests the list of supported sensor types.Params: - none -","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorGet.html","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorGet","type":"module"},{"doc":"This module implements command SENSOR_MULTILEVEL_SUPPORTED_SENSOR_REPORT of the COMMAND_CLASS_SENSOR_MULTILEVEL command class. This command is used to advertise the supported Sensor Types by a supporting node.Params::sensor_types - list of :temperature or :illuminance or :power or :humidity etc. (required)","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.html","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.html#t:sensor_type/0","title":"Grizzly.ZWave.Commands.SensorMultilevelSupportedSensorReport.sensor_type/0","type":"type"},{"doc":"This command is sent to the unsolicited destinations when a Smart Start inclusion starts.The Add Node Status Command MUST be issued after the Smart Start inclusion and S2 bootstrapping attempts took place.Params: :seq_number - the sequence number for the networked command (required):dsk - a DSK string for the device see Grizzly.ZWave.DSK for more more information (required)","ref":"Grizzly.ZWave.Commands.SmartStartJoinStarted.html","title":"Grizzly.ZWave.Commands.SmartStartJoinStarted","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SmartStartJoinStarted.html#t:param/0","title":"Grizzly.ZWave.Commands.SmartStartJoinStarted.param/0","type":"type"},{"doc":"This command is used to initiate the execution of a command and to request the immediate and future status of the process being initiated.Params::status_updates - used to allow a receiving node to advertise application status updates in future Supervision Report Commands (required):session_id - used to detect redundant invocations due to retransmissions (required):encapsulated_command - an encapsulated command (required) -see ZWave Transport Encapsulation Command Class Specifications","ref":"Grizzly.ZWave.Commands.SupervisionGet.html","title":"Grizzly.ZWave.Commands.SupervisionGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionGet.html#t:param/0","title":"Grizzly.ZWave.Commands.SupervisionGet.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionGet.html#t:status_updates/0","title":"Grizzly.ZWave.Commands.SupervisionGet.status_updates/0","type":"type"},{"doc":"This command is used to advertise the status of one or more command process(es).Params::more_status_updates - used to advertise if more Supervision Reports follow for the actual Session ID (required):session_id - carries the same value as the Session ID field of the Supervision Get Command which initiated this session (required):status - the current status of the command process, one of :no_support, :working, :fail or :success (required):duration - the time in seconds needed to complete the current operation (required)","ref":"Grizzly.ZWave.Commands.SupervisionReport.html","title":"Grizzly.ZWave.Commands.SupervisionReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionReport.html#t:more_status_updates/0","title":"Grizzly.ZWave.Commands.SupervisionReport.more_status_updates/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SupervisionReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.SupervisionReport.html#t:status/0","title":"Grizzly.ZWave.Commands.SupervisionReport.status/0","type":"type"},{"doc":"Get the command value of a binary switchParams: -none-","ref":"Grizzly.ZWave.Commands.SwitchBinaryGet.html","title":"Grizzly.ZWave.Commands.SwitchBinaryGet","type":"module"},{"doc":"Module for the SWITCH_BINARY_REPORT commandParams::target_value - :on or :off(required):duration - 0-255 (optional)","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html","title":"Grizzly.ZWave.Commands.SwitchBinaryReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html#encode_target_value/1","title":"Grizzly.ZWave.Commands.SwitchBinaryReport.encode_target_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinaryReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchBinaryReport.param/0","type":"type"},{"doc":"Module for the SWITCH_BINARY_SET commandParams::target_value - :on or :off(required):duration - 0-255 (optional v2)","ref":"Grizzly.ZWave.Commands.SwitchBinarySet.html","title":"Grizzly.ZWave.Commands.SwitchBinarySet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinarySet.html#encode_target_value/1","title":"Grizzly.ZWave.Commands.SwitchBinarySet.encode_target_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchBinarySet.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchBinarySet.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_GETParams: - none -","ref":"Grizzly.ZWave.Commands.SwitchMultilevelGet.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelGet","type":"module"},{"doc":"Module for the SWITCH_MULTILEVEL_REPORTParams::value - ':off or a value betweem 1 and 100:duration - How long the switch should take to reach target value, 0 -&gt; instantly, 1..127 -&gt; seconds, 128..253 -&gt; minutes, 255 -&gt; unknown (optional v2)","ref":"Grizzly.ZWave.Commands.SwitchMultilevelReport.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelReport.html#encode_value/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelReport.encode_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelReport.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchMultilevelReport.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_SETParams::target_value - ':off, :previous or a value betweem 1 and 99:duration - How long the switch should take to reach target value, 0 -&gt; instantly, 1..127 -&gt; seconds, 128..254 -&gt; minutes, 256 -&gt; factory default (option v2)","ref":"Grizzly.ZWave.Commands.SwitchMultilevelSet.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelSet.html#encode_target_value/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelSet.encode_target_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelSet.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchMultilevelSet.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_START_LEVEL_CHANGEParams::up_down - initiating change of level :up or :down:duration - seconds to take to go from 0 to 99, or 99 to 0 - optional v2 Note that support for secodary switch introduced in v3 is deprecated and ignored here. A controller SHOULD ignore Start Level; it is always ignored here.","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html#decode_up_down/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.decode_up_down/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html#encode_up_down/1","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.encode_up_down/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.html#t:param/0","title":"Grizzly.ZWave.Commands.SwitchMultilevelStartLevelChange.param/0","type":"type"},{"doc":"Module for the SWITCH_MULTILEVEL_STOP_LEVEL_CHANGEParams: -none-","ref":"Grizzly.ZWave.Commands.SwitchMultilevelStopLevelChange.html","title":"Grizzly.ZWave.Commands.SwitchMultilevelStopLevelChange","type":"module"},{"doc":"This module implements command THERMOSTAT_FAN_MODE_GET of the COMMAND_CLASS_THERMOSTAT_FAN_MODE command classThis command is used to request the fan mode.Params: -none-","ref":"Grizzly.ZWave.Commands.ThermostatFanModeGet.html","title":"Grizzly.ZWave.Commands.ThermostatFanModeGet","type":"module"},{"doc":"This module implement command THERMOSTAT_FAN_MODE_REPORT of the COMMAND_CLASS_THERMOSTAT_FAN_MODE command classThis command is used to report the fan mode.Params::mode - one of :auto_low | :low | :auto_high | :high (required)","ref":"Grizzly.ZWave.Commands.ThermostatFanModeReport.html","title":"Grizzly.ZWave.Commands.ThermostatFanModeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatFanModeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatFanModeReport.param/0","type":"type"},{"doc":"This module implement command THERMOSTAT_FAN_MODE_SET of the COMMAND_CLASS_THERMOSTAT_FAN_MODE command classThis command is used to set the fan mode.Params::mode - one of :auto_low | :low | :auto_high | :high (required)","ref":"Grizzly.ZWave.Commands.ThermostatFanModeSet.html","title":"Grizzly.ZWave.Commands.ThermostatFanModeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatFanModeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatFanModeSet.param/0","type":"type"},{"doc":"This module implement command THERMOSTAT_FAN_STATE_GET of the COMMAND_CLASS_THERMOSTAT_FAN_STATE command classThis command is used to request the fan operating state.Params: -none-","ref":"Grizzly.ZWave.Commands.ThermostatFanStateGet.html","title":"Grizzly.ZWave.Commands.ThermostatFanStateGet","type":"module"},{"doc":"This module implements command THERMOSTAT_FAN_STATE_REPORT of the COMMAND_CLASS_THERMOSTAT_FAN_STATE command class. This command is used to report the fan operating state of the thermostat device.Params::state - the state of the fan (required)","ref":"Grizzly.ZWave.Commands.ThermostatFanStateReport.html","title":"Grizzly.ZWave.Commands.ThermostatFanStateReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatFanStateReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatFanStateReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_MODE_GET of the command class COMMAND_CLASS_THERMOSTAT_MODE.The command is used to request the current mode set at the receiving node.Params: - none -","ref":"Grizzly.ZWave.Commands.ThermostatModeGet.html","title":"Grizzly.ZWave.Commands.ThermostatModeGet","type":"module"},{"doc":"This module implements command THERMOSTAT_MODE_REPORT of the COMMAND_CLASS_THERMOSTAT_MODE command class.This command is used to report the mode from the thermostat device.Params::mode - the mode of the thermostat, see ThermostatMode (required)","ref":"Grizzly.ZWave.Commands.ThermostatModeReport.html","title":"Grizzly.ZWave.Commands.ThermostatModeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatModeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatModeReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_MODE_SET of the COMMAND_CLASS_THERMOSTAT_MODE command class.This command is used to set the mode from the thermostat device.Params::mode - the mode of the thermostat, see ThermostatMode (required)","ref":"Grizzly.ZWave.Commands.ThermostatModeSet.html","title":"Grizzly.ZWave.Commands.ThermostatModeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatModeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatModeSet.param/0","type":"type"},{"doc":"This module implement command THERMOSTAT_OPERATING_STATE_GET of the COMMAND_CLASS_THERMOSTAT_OPERATING_STATE command classThis command gets the operating state of the thermostat.Params: -none-","ref":"Grizzly.ZWave.Commands.ThermostatOperatingStateGet.html","title":"Grizzly.ZWave.Commands.ThermostatOperatingStateGet","type":"module"},{"doc":"This module implement command THERMOSTAT_OPERATING_STATE_REPORT (v1) of the COMMAND_CLASS_THERMOSTAT_OPERATING_STATE command classThis command report the operating state of the thermostat.Params::state - the operating state (required)","ref":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport.html","title":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatOperatingStateReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETBACK_GET of the command class COMMAND_CLASS_THERMOSTAT_SETBACK.This command is used to request the current setback state of the thermostat.Params: - none -","ref":"Grizzly.ZWave.Commands.ThermostatSetbackGet.html","title":"Grizzly.ZWave.Commands.ThermostatSetbackGet","type":"module"},{"doc":"This module implements command THERMOSTAT_SETBACK_REPORT of the COMMAND_CLASS_THERMOSTAT_SETBACK command class. This command is used to report the setback state of the thermostat.Params::type - the setback type (required):state - the setback state (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetbackReport.html","title":"Grizzly.ZWave.Commands.ThermostatSetbackReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetbackReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetbackReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETBACK_SET of the COMMAND_CLASS_THERMOSTAT_SETBACK command class. This command is used to set the setback state of the thermostat.Params::type - the type the setback (required):state - the setback state (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetbackSet.html","title":"Grizzly.ZWave.Commands.ThermostatSetbackSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetbackSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetbackSet.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETPOINT_GET of the COMMAND_CLASS_THERMOSTAT_SETPOINT command class.This command is used to request the target value for a given setpoint type.Params::type - the setback type (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetpointGet.html","title":"Grizzly.ZWave.Commands.ThermostatSetpointGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetpointGet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetpointGet.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETPOINT_REPORT of the COMMAND_CLASS_THERMOSTAT_SETPOINT command class.This command is used to advertise the target value for a given setpoint type.Params::type - the setpoint type (required):scale - the setpoint scale (required):value - the value of the setpoint (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetpointReport.html","title":"Grizzly.ZWave.Commands.ThermostatSetpointReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetpointReport.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetpointReport.param/0","type":"type"},{"doc":"This module implements command THERMOSTAT_SETPOINT_SET of the COMMAND_CLASS_THERMOSTAT_SETPOINT command class.This command is used to set the target value for a given setpoint type.Params::type - the setpoint type (required):scale - the setpoint scale (required):value - the value of the setpoint (required)","ref":"Grizzly.ZWave.Commands.ThermostatSetpointSet.html","title":"Grizzly.ZWave.Commands.ThermostatSetpointSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ThermostatSetpointSet.html#t:param/0","title":"Grizzly.ZWave.Commands.ThermostatSetpointSet.param/0","type":"type"},{"doc":"This module implements command USER_CODE_GET of the COMMAND_CLASS_USER_CODE command class.This command is used to request the User Code of a specific User Identifier.Params:user_id - the user identifier, an integer between 1 and 255 (required)","ref":"Grizzly.ZWave.Commands.UserCodeGet.html","title":"Grizzly.ZWave.Commands.UserCodeGet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeGet.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeGet.param/0","type":"type"},{"doc":"UserCodeReport reports on a user codeParams::user_id - the id of the user code (required):user_id_status - the status if the user id slot (required):user_code - a 4 - 10 user code pin in string format (required)","ref":"Grizzly.ZWave.Commands.UserCodeReport.html","title":"Grizzly.ZWave.Commands.UserCodeReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeReport.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeReport.html#t:user_id_status/0","title":"Grizzly.ZWave.Commands.UserCodeReport.user_id_status/0","type":"type"},{"doc":"UserCodeSet sets the user codeParams::user_id - the id of the user code (required):user_id_status - the status if the user id slot (required):user_code - a 4 - 10 user code pin in string format (required)","ref":"Grizzly.ZWave.Commands.UserCodeSet.html","title":"Grizzly.ZWave.Commands.UserCodeSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeSet.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeSet.param/0","type":"type"},{"doc":"This module implements the command USERS_NUMBER_GET from the COMMAND_CLASS_USER_CODE command class.This command is used to request the number of user codes supportedParams: -none-","ref":"Grizzly.ZWave.Commands.UserCodeUsersNumberGet.html","title":"Grizzly.ZWave.Commands.UserCodeUsersNumberGet","type":"module"},{"doc":"Gets the number of supported user codesParams:supported_users - the number of supported users","ref":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport.html","title":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport.html#t:param/0","title":"Grizzly.ZWave.Commands.UserCodeUsersNumberReport.param/0","type":"type"},{"doc":"This module implements command VERSION_GET of command class COMMAND_CLASS_VERSIONParams: - none -","ref":"Grizzly.ZWave.Commands.VersionGet.html","title":"Grizzly.ZWave.Commands.VersionGet","type":"module"},{"doc":"This module implements command VERSION_REPORT of command class COMMAND_CLASS_VERSIONParams::library_type - The type of Z-Wave device library is running (required):protocol_version - The &quot;version.sub&quot; of the implemented Z-Wave protocol (required):firmware_version - The &quot;version.sub&quot; of the firmware (required):hardware_version - the hardware version - (optional V1, required V2 and above):other_firmware_versions - The list of &quot;version.sub&quot; of the other firmware targets (optional V1, required V2 and above)","ref":"Grizzly.ZWave.Commands.VersionReport.html","title":"Grizzly.ZWave.Commands.VersionReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:firmware_version/0","title":"Grizzly.ZWave.Commands.VersionReport.firmware_version/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:library_type/0","title":"Grizzly.ZWave.Commands.VersionReport.library_type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:param/0","title":"Grizzly.ZWave.Commands.VersionReport.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.VersionReport.html#t:protocol_version/0","title":"Grizzly.ZWave.Commands.VersionReport.protocol_version/0","type":"type"},{"doc":"This module implements the WAKE_UP_INTERVAL_CAPABILITIES_GET command of the COMMAND_CLASS_WAKE_UP command class.Params: -none-","ref":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesGet.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesGet","type":"module"},{"doc":"This module implements the WAKE_UP_INTERVAL_CAPABILITIES_REPORT command of the COMMAND_CLASS_WAKE_UP command class.Params::minimum_seconds - the minimum Wake Up Interval supported by the sending node - v2:maximum_seconds - the maximum Wake Up Interval supported by the sending node - v2:default_seconds - the default Wake Up Interval value for the sending node. - v2:step_seconds - the resolution of valid Wake Up Intervals values for the sending node - v2:on_demand - whether the supporting node supports the Wake Up On Demand functionality - v3","ref":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport.html#t:param/0","title":"Grizzly.ZWave.Commands.WakeUpIntervalCapabilitiesReport.param/0","type":"type"},{"doc":"This module implements the WAKE_UP_INTERVAL_GET command of the COMMAND_CLASS_WAKE_UP command classParams: - none -","ref":"Grizzly.ZWave.Commands.WakeUpIntervalGet.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalGet","type":"module"},{"doc":"This module implements the WAKE_UP_INTERVAL_REPORT command of the COMMAND_CLASS_WAKE_UP command class.Params::seconds - the time in seconds between Wake Up periods at the sending node (required):node_id - the Wake Up destination NodeID configured at the sending node (required)","ref":"Grizzly.ZWave.Commands.WakeUpIntervalReport.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.WakeUpIntervalReport.html#t:param/0","title":"Grizzly.ZWave.Commands.WakeUpIntervalReport.param/0","type":"type"},{"doc":"This module implements the WAKE_UP_INTERVAL_SET command of the COMMAND_CLASS_WAKE_UP command class.Params::seconds - the time in seconds between Wake Up periods at the sending node (required):node_id - the Wake Up destination NodeID configured at the sending node (required)","ref":"Grizzly.ZWave.Commands.WakeUpIntervalSet.html","title":"Grizzly.ZWave.Commands.WakeUpIntervalSet","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.WakeUpIntervalSet.html#t:param/0","title":"Grizzly.ZWave.Commands.WakeUpIntervalSet.param/0","type":"type"},{"doc":"This module implements the WAKE_UP_NO_MORE_INFORMATION command of the COMMAND_CLASS_WAKE_UP command classParams: - none -","ref":"Grizzly.ZWave.Commands.WakeUpNoMoreInformation.html","title":"Grizzly.ZWave.Commands.WakeUpNoMoreInformation","type":"module"},{"doc":"This module implements the WAKE_UP_NOTIFICATION command of the COMMAND_CLASS_WAKE_UP command classParams: - none -","ref":"Grizzly.ZWave.Commands.WakeUpNotification.html","title":"Grizzly.ZWave.Commands.WakeUpNotification","type":"module"},{"doc":"The Z/IP Packet keep alive commandParams::ack_flag - the flag if the receiving node should acknowledge the keep alive packet or not","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html","title":"Grizzly.ZWave.Commands.ZIPKeepAlive","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html#encode_ack_flag/1","title":"Grizzly.ZWave.Commands.ZIPKeepAlive.encode_ack_flag/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html#t:ack_flag/0","title":"Grizzly.ZWave.Commands.ZIPKeepAlive.ack_flag/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPKeepAlive.html#t:param/0","title":"Grizzly.ZWave.Commands.ZIPKeepAlive.param/0","type":"type"},{"doc":"Command for sending Z-Wave commands via Z/IP","ref":"Grizzly.ZWave.Commands.ZIPPacket.html","title":"Grizzly.ZWave.Commands.ZIPPacket","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#ack_response?/1","title":"Grizzly.ZWave.Commands.ZIPPacket.ack_response?/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#command_name/1","title":"Grizzly.ZWave.Commands.ZIPPacket.command_name/1","type":"function"},{"doc":"Get the extension by extension name","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#extension/3","title":"Grizzly.ZWave.Commands.ZIPPacket.extension/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#flag_to_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.flag_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#make_ack_response/1","title":"Grizzly.ZWave.Commands.ZIPPacket.make_ack_response/1","type":"function"},{"doc":"Make a :nack_response","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#make_nack_response/1","title":"Grizzly.ZWave.Commands.ZIPPacket.make_nack_response/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#make_nack_waiting_response/2","title":"Grizzly.ZWave.Commands.ZIPPacket.make_nack_waiting_response/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#meta_to_byte/3","title":"Grizzly.ZWave.Commands.ZIPPacket.meta_to_byte/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#with_zwave_command/3","title":"Grizzly.ZWave.Commands.ZIPPacket.with_zwave_command/3","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#t:flag/0","title":"Grizzly.ZWave.Commands.ZIPPacket.flag/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.html#t:param/0","title":"Grizzly.ZWave.Commands.ZIPPacket.param/0","type":"type"},{"doc":"Functions for working with the header extension in a Z/IP Packet.","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions","type":"module"},{"doc":"Try to parse a binary string into HeaderExtensions.t()","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#from_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#to_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#t:encapsulation_format_info/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.encapsulation_format_info/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.html#t:extension/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.extension/0","type":"type"},{"doc":"Encapsulation format info for a Z/IP Packet","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#crc16_from_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.crc16_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#security_to_security_from_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.security_to_security_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#security_to_security_to_byte/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.security_to_security_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#to_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.html#t:security/0","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.EncapsulationFormatInfo.security/0","type":"type"},{"doc":"Expected Delay is the header extension that is found in a Z/IP Command to indicate how many seconds until the command will be received by a node and processed.Non-Sleeping devices: this extension does not applyFrequently Listening Nodes: 1 secondsSleeping devices: &gt; 1","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay.html#to_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.ExpectedDelay.to_binary/1","type":"function"},{"doc":"The installation and maintenance report for a Z/IP Packet","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.html","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.html#from_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.html#ime_from_binary/1","title":"Grizzly.ZWave.Commands.ZIPPacket.HeaderExtensions.InstallationAndMaintenanceReport.ime_from_binary/1","type":"function"},{"doc":"Module for working with the SmartStart and S2 DSKs","ref":"Grizzly.ZWave.DSK.html","title":"Grizzly.ZWave.DSK","type":"module"},{"doc":"Take a binary representation of the DSK and change it into the string representation","ref":"Grizzly.ZWave.DSK.html#binary_to_string/1","title":"Grizzly.ZWave.DSK.binary_to_string/1","type":"function"},{"doc":"Take a string representation of the DSK and change it into the binary representation","ref":"Grizzly.ZWave.DSK.html#string_to_binary/1","title":"Grizzly.ZWave.DSK.string_to_binary/1","type":"function"},{"doc":"The DSK binary is the elixir binary string form of the DSKThe format is &lt;&lt;b1, b2, b3, ... b16&gt;&gt;That is 16 bytes.An example of this would be:&lt;&lt;196, 109, 73, 131, 38, 196, 119, 227, 62, 101, 131, 175, 15, 165, 14, 39&gt;&gt;","ref":"Grizzly.ZWave.DSK.html#t:dsk_binary/0","title":"Grizzly.ZWave.DSK.dsk_binary/0","type":"type"},{"doc":"The DSK string is the string version of the DSKThe general format is XXXXX-XXXXX-XXXXX-XXXXX-XXXXX-XXXXX-XXXXX-XXXXXThat is 8 blocks of 16 bit integers separated by a dash.An example of this would be 50285-18819-09924-30691-15973-33711-04005-03623","ref":"Grizzly.ZWave.DSK.html#t:dsk_string/0","title":"Grizzly.ZWave.DSK.dsk_string/0","type":"type"},{"doc":"Z-Wave device classes","ref":"Grizzly.ZWave.DeviceClasses.html","title":"Grizzly.ZWave.DeviceClasses","type":"module"},{"doc":"Try to make a basic device class from a byte","ref":"Grizzly.ZWave.DeviceClasses.html#basic_device_class_from_byte/1","title":"Grizzly.ZWave.DeviceClasses.basic_device_class_from_byte/1","type":"function"},{"doc":"Make a byte from a device class","ref":"Grizzly.ZWave.DeviceClasses.html#basic_device_class_to_byte/1","title":"Grizzly.ZWave.DeviceClasses.basic_device_class_to_byte/1","type":"function"},{"doc":"Try to get the generic device class for the byte","ref":"Grizzly.ZWave.DeviceClasses.html#generic_device_class_from_byte/1","title":"Grizzly.ZWave.DeviceClasses.generic_device_class_from_byte/1","type":"function"},{"doc":"Turn the generic device class into a byte","ref":"Grizzly.ZWave.DeviceClasses.html#generic_device_class_to_byte/1","title":"Grizzly.ZWave.DeviceClasses.generic_device_class_to_byte/1","type":"function"},{"doc":"Try to get the specific device class from the byte given the generic device class","ref":"Grizzly.ZWave.DeviceClasses.html#specific_device_class_from_byte/2","title":"Grizzly.ZWave.DeviceClasses.specific_device_class_from_byte/2","type":"function"},{"doc":"Make the specific device class into a byte","ref":"Grizzly.ZWave.DeviceClasses.html#specific_device_class_to_byte/2","title":"Grizzly.ZWave.DeviceClasses.specific_device_class_to_byte/2","type":"function"},{"doc":"","ref":"Grizzly.ZWave.DeviceClasses.html#t:basic_device_class/0","title":"Grizzly.ZWave.DeviceClasses.basic_device_class/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.DeviceClasses.html#t:generic_device_class/0","title":"Grizzly.ZWave.DeviceClasses.generic_device_class/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.DeviceClasses.html#t:specific_device_class/0","title":"Grizzly.ZWave.DeviceClasses.specific_device_class/0","type":"type"},{"doc":"The installer icon type is used in Z-Wave Plus devices to allow interoperability with generic Z-Wave graphical user interfaces.These interfaces are useful when using generic Z-Wave tooling and debugging to allow the user to get a meaningful representation of any product included in the network, and is mandatory according the Z-Wave Plus specification.See SDS11847 Z-Wave Plus Device Type Specification.pdf Appendix A provided by Silicon Labs for more information.","ref":"Grizzly.ZWave.IconType.html","title":"Grizzly.ZWave.IconType","type":"module"},{"doc":"Get the icon type's name from a 16-bit integer value","ref":"Grizzly.ZWave.IconType.html#to_name/1","title":"Grizzly.ZWave.IconType.to_name/1","type":"function"},{"doc":"Get the 16-bit integer value from the icon type's name","ref":"Grizzly.ZWave.IconType.html#to_value/1","title":"Grizzly.ZWave.IconType.to_value/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.IconType.html#t:name/0","title":"Grizzly.ZWave.IconType.name/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.IconType.html#t:value/0","title":"Grizzly.ZWave.IconType.value/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html","title":"Grizzly.ZWave.Notifications","type":"module"},{"doc":"Get the event from the byte given the notification type","ref":"Grizzly.ZWave.Notifications.html#event_from_byte/2","title":"Grizzly.ZWave.Notifications.event_from_byte/2","type":"function"},{"doc":"Get the event byte given the event type","ref":"Grizzly.ZWave.Notifications.html#event_to_byte/2","title":"Grizzly.ZWave.Notifications.event_to_byte/2","type":"function"},{"doc":"Get the type from the byte","ref":"Grizzly.ZWave.Notifications.html#type_from_byte/1","title":"Grizzly.ZWave.Notifications.type_from_byte/1","type":"function"},{"doc":"Get the byte for the event name","ref":"Grizzly.ZWave.Notifications.html#type_to_byte/1","title":"Grizzly.ZWave.Notifications.type_to_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:event/0","title":"Grizzly.ZWave.Notifications.event/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:type/0","title":"Grizzly.ZWave.Notifications.type/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Notifications.html#t:zwave_alarm_status/0","title":"Grizzly.ZWave.Notifications.zwave_alarm_status/0","type":"type"},{"doc":"Helpers for security","ref":"Grizzly.ZWave.Security.html","title":"Grizzly.ZWave.Security","type":"module"},{"doc":"","ref":"Grizzly.ZWave.Security.html#byte_to_keys/1","title":"Grizzly.ZWave.Security.byte_to_keys/1","type":"function"},{"doc":"Decode a byte representation of the key exchanged failed type","ref":"Grizzly.ZWave.Security.html#failed_type_from_byte/1","title":"Grizzly.ZWave.Security.failed_type_from_byte/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Security.html#failed_type_to_byte/1","title":"Grizzly.ZWave.Security.failed_type_to_byte/1","type":"function"},{"doc":"Gets the highest security level key from a key listSince Z-Wave will work at the highest S2 security group available on a node, if multiple groups are in a list of keys it will assume that highest level is the security level of the node who provided this list.If the node S0 security Z-Wave will response with granted keys with the lone key being S0.","ref":"Grizzly.ZWave.Security.html#get_highest_level/1","title":"Grizzly.ZWave.Security.get_highest_level/1","type":"function"},{"doc":"Get the byte representation of a key.The key :none is an invalid key to encode to, so this function does not support encoding to that key.","ref":"Grizzly.ZWave.Security.html#key_byte/1","title":"Grizzly.ZWave.Security.key_byte/1","type":"function"},{"doc":"Get the list of available security keys","ref":"Grizzly.ZWave.Security.html#keys/0","title":"Grizzly.ZWave.Security.keys/0","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Security.html#keys_to_byte/1","title":"Grizzly.ZWave.Security.keys_to_byte/1","type":"function"},{"doc":"Validate the user input pin length, should be a 16 bit number","ref":"Grizzly.ZWave.Security.html#validate_user_input_pin_length/1","title":"Grizzly.ZWave.Security.validate_user_input_pin_length/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.Security.html#t:key/0","title":"Grizzly.ZWave.Security.key/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.Security.html#t:key_byte/0","title":"Grizzly.ZWave.Security.key_byte/0","type":"type"},{"doc":"Possible key exchange failures:none - Bootstrapping was successful:key - No match between requested and granted keys:scheme - no scheme is supported by the controller or joining node:decrypt - joining node failed to decrypt the input pin from the value. Wrong input value/DSK from user:cancel - user has canceled the S2 bootstrapping:auth - the echo kex change frame does not match the earlier exchanged frame:get - the joining node requested a key that was not granted by the controller at an earlier stage:verify - the joining node cannot verify and decrypt the exchanged key:report - the including node transmitted a frame containing a different key than what was currently being exchanged","ref":"Grizzly.ZWave.Security.html#t:key_exchange_fail_type/0","title":"Grizzly.ZWave.Security.key_exchange_fail_type/0","type":"type"},{"doc":"Meta Extension support for SmartRent devices","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html","title":"Grizzly.ZWave.SmartStart.MetaExtension","type":"behaviour"},{"doc":"Take an Extension.t() and turn it into a binary","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#extension_to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.extension_to_binary/1","type":"function"},{"doc":"Given a binary string with meta extensions, can be in any order, decode it and return a list of MetaExtension.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#extensions_from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.extensions_from_binary/1","type":"function"},{"doc":"Take a list of Extension.t()s and turn them into a binary string","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#extensions_to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.extensions_to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#c:from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.from_binary/1","type":"callback"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#c:to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.to_binary/1","type":"callback"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.t/0","type":"type"},{"doc":"This extension is used to advertise the Security keys to grant during S2 bootstrapping to a SmartStart node in the provisioning list For more information about S2 security see the Grizzly.Security module","ref":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining","type":"module"},{"doc":"Create a binary string from an AdvancedJoining.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.from_binary/1","type":"function"},{"doc":"Create a new AdvancedJoining.t() This will validate the keys passed in are valid S2 keys. If a key is not a valid S2 key this function will return {:error, :invalid_keys}. The key parameter cannot be an empty list. If an empty list is passed in then this function will return {:error, :empty_keys}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.html#new/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.new/1","type":"function"},{"doc":"Create an AdvancedJoining.t() from a binary string If the binary string does not have the critical bit set then this function will return {:error, :critical_bit_not_set}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.AdvancedJoining.t/0","type":"type"},{"doc":"This extension is used to advertise the bootstrapping mode to use when including the node advertised in the provisioning list","ref":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode","type":"module"},{"doc":"Make a BootstrappingMode.t() from a binaryThe binary string for this extension requires the critical bit to be set and if it is not this function will return {:error, :critical_bit_not_set}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.from_binary/1","type":"function"},{"doc":"Create a BootstrappingMode.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.html#new/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.new/1","type":"function"},{"doc":"Make a binary from a BootstrappingMode.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.to_binary/1","type":"function"},{"doc":"The modes are::security_2 - the node must be manually set to learn mode and follow the S2 bootstrapping instructions:smart_start - the node will use S2 bootstrapping automatically using the SmartStart functionality","ref":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.html#t:mode/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.mode/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.BootstrappingMode.t/0","type":"type"},{"doc":"This extension is used to advertise the location assigned to the supporting nodeThe location string cannot contain underscores and cannot end with a dash.The location string can contain a period (.) but a sublocation cannot end a dash. For example:123.123-.123The above location invalid. To make it valid remove the - before ..A node's location cannot be more than 62 bytes.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation","type":"module"},{"doc":"Make a LocationInformation.t() from a binaryIf the location contains characters that are not valid this function will return {:error, reason} where reason is::contains_underscore:ends_with_dash:location_too_long:sublocation_ends_with_dashIf the critical bit set in the binary this function will return {:error, :critical_bit_set}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.from_binary/1","type":"function"},{"doc":"Make a new LocationInformation.t() from a location stringIf the location contains characters that are not valid this function will return {:error, reason} where reason is::contains_underscore:ends_with_dash:location_too_long:sublocation_ends_with_dash","ref":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.html#new/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.new/1","type":"function"},{"doc":"Make a LocationInformation.t() into a binary","ref":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.LocationInformation.t/0","type":"type"},{"doc":"This is used to advertise if a power constrained Smart Start node will issue inclusion request at a higher interval value than the default 512 seconds.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval","type":"module"},{"doc":"Make a MaxInclusionRequestInterval.t() from a binary stringIf the interval provided in the binary is invalid this function will return {:error, :interval_too_big | :interval_too_small}. See the typedoc for more information regarding the interval specification.If the critical bit is set this is considered invalid to the specification and the function will return {:error, :critical_bit_set}.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.html#new/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.new/1","type":"function"},{"doc":"Make a binary string from a MaxInclusionRequestInterval.t()If the interval provided in the binary is invalid this function will return {:error, :interval_too_big | :interval_too_small}. See the typedoc for more information regarding the interval specification.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.to_binary/1","type":"function"},{"doc":"The interval (in seconds) must be in the range of 640..12672 inclusive, and has to be in steps of 128 seconds.So after 640 the next valid interval is 640 + 128 which is 768 seconds.See SDS13944 Node Provisioning Information Type Registry.pdf section 3.1.2.3 for more information.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.html#t:interval/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.interval/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.MaxInclusionRequestInterval.t/0","type":"type"},{"doc":"This extension is used to advertise the name assigned to the supporting nodeThe name string cannot contain underscores and cannot end with a dash.A node's name cannot be more than 62 bytes.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation","type":"module"},{"doc":"Make a NameInformation.t() from a binaryIf the name contains characters that are not valid this function will return {:error, reason} where reason is::contains_underscore:ends_with_dash:name_too_longIf the critical bit set in the binary this function will return {:error, :critical_bit_set}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.html#new/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.new/1","type":"function"},{"doc":"Make a NameInformation.t() into a binary","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.NameInformation.t/0","type":"type"},{"doc":"This extension is used to advertise if the node is in the network and its assigned node id","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus","type":"module"},{"doc":"Make a NetworkStatus.t() from a binary stringThe binary string's critical bit MUST not be set. If it is this function will return {:error, :critical_bit_set}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.from_binary/1","type":"function"},{"doc":"Create a NetworkStatus.t()If the node is not included into the network the node_id has to be equal to 0. If the node has been included into the network and is either functional or failing then it has to have a node_id greater than 0.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.html#new/2","title":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.new/2","type":"function"},{"doc":"Make a binary string from a NetworkStatus.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.to_binary/1","type":"function"},{"doc":"The different network statuses are::not_in_network - the node in the provisioning list is not included in the network:included - the node in the provisioning list is included in the network and is functional:failing - the node in the provisioning list is included in the network but is now marked as failing","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.html#t:network_status/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.network_status/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.NetworkStatus.t/0","type":"type"},{"doc":"This Information Type is used to advertise the product identifying data of a supporting node.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId","type":"module"},{"doc":"Make a ProductId.t() from a binary stringAccording to the specification for this extension the critical bit must not be set. If it is then the binary is not consider valid and should be ignored.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.from_binary/1","type":"function"},{"doc":"Make a new ProductId.t()If a param is invalid this function will return {:error, :invalid_params, param(), param_value}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html#new/4","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.new/4","type":"function"},{"doc":"Build a binary from a ProductId.t()The arguments for the params() other than application version should be unsigned 16 bit integers.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.to_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html#t:param/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.param/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.t/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.html#t:u16/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductId.u16/0","type":"type"},{"doc":"This Information Type is used to advertise the product type data of a supporting node","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType","type":"module"},{"doc":"Make a ProductType.t() from a binary stringAccording to the specification for this extension the critical bit must not be set. If it is then the binary is not consider valid and should be ignored.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.from_binary/1","type":"function"},{"doc":"Make a new ProductType.t()If there is invalid device classes or installer icon type with will return {:error, reason} where reason is::invalid_generic_device_class - the generic device class could not be encoded into its byte representation:invalid_specific_device_class - the specific device class could nto be encoded into its byte representation:unknown_icon_type - the installer icon type cannot be encoded into its byte representation","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.html#new/3","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.new/3","type":"function"},{"doc":"Build a binary from a ProductType.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.to_binary/1","type":"function"},{"doc":"The generic and specific device classes are what is advertised in the Node Information Frame (NIF)The installer icon for the specific device see Grizzly.IconType for more information","ref":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.ProductType.t/0","type":"type"},{"doc":"This extension is used to advertise the SmartStart inclusion setting of the provisioning list entry","ref":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting","type":"module"},{"doc":"Make a binary from a SmartStartInclusionSetting.t()If the setting is invalid this function will return {:error, :invalid_setting}If the binary does not have the critical bit set then this function will return {:error, :critical_bit_not_set}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.from_binary/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.html#new/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.new/1","type":"function"},{"doc":"Make a SmartStartInclusionSetting.t() from a binaryIf the setting is invalid this function will return {:error, :invalid_setting}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.to_binary/1","type":"function"},{"doc":"The setting for SmartStart inclusion. This tells the controller if it must listen and/or include a node in the network when receiving SmartStart inclusion requests.:pending - the node will be added to the network when it issues SmartStart inclusion requests.:passive - this node is unlikely to issues a SmartStart inclusion request and SmartStart inclusion requests will be ignored from this node by the Z/IP Gateway. All nodes in the list with this setting must be updated to :pending when Provisioning List Iteration Get command is issued.:ignored - All SmartStart inclusion request are ignored from this node until updated via Z/IP Client (Grizzly) or a controlling node.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.html#t:setting/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.setting/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.SmartStartInclusionSetting.t/0","type":"type"},{"doc":"This is used to advertise 16 bytes of manufactured-defined information that is unique for a given product.Z-Wave UUIDs are not limited to the format outlined in RFC 4122 but can also be ASCII characters and a relevant prefix.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16","type":"module"},{"doc":"Take a binary string and try to make a UUID16.t() from itIf the critical bit is set in teh binary this will return {:error, :critical_bit_set} and the information should be ignored.If the format in the binary is not part of the defined Z-Wave specification this will return {:error, :invalid_format}","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#from_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.from_binary/1","type":"function"},{"doc":"Make a new UUID16.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#new/2","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.new/2","type":"function"},{"doc":"Make a binary string from a UUID16.t()","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#to_binary/1","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.to_binary/1","type":"function"},{"doc":"The three formats that the Z-Wave UUID can be formatted in are :ascii, :hex, or :rfc4122.Both :ascii and :hex can also have the prefix sn: or UUID:.Valid :hex formatted UUIDs look like:0102030405060708090A141516171819sn:0102030405060708090A141516171819UUID:0102030405060708090A141516171819Valid :ascii formatted UUIDs look like:Hello Elixir!!!sn:Hello Elixir!!!UUID:Hello Elixir!!!Lastly rfc4122 format looks like 58D5E212-165B-4CA0-909B-C86B9CEE0111 where every two digits make up one hex value.More information about RFC 4122 and the specification format can be found here.","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#t:format/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.format/0","type":"type"},{"doc":"","ref":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.html#t:t/0","title":"Grizzly.ZWave.SmartStart.MetaExtension.UUID16.t/0","type":"type"},{"doc":"Generates the scaffolding for a new Z-Wave Command mix zwave.gen.command ThermostatModeSet Thermostat modeThe pattern is mix zwave.gen.command CommandModuleName CommandClassModule params....Flags:--no-save - will print the generated module out to the console--target-dir &lt;path&gt; - will generate the new module at the provided path--no_test - if set, will not generate a test file","ref":"Mix.Tasks.Zwave.Gen.Command.html","title":"Mix.Tasks.Zwave.Gen.Command","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Zwave.Gen.Command.html#run/1","title":"Mix.Tasks.Zwave.Gen.Command.run/1","type":"function"},{"doc":"Generates the scaffolding for a new Z-Wave Command mix zwave.gen.command_class ThermostatThe pattern is mix zwave.gen.command_class CommandClassModuleFlags:--no-save - will print the generated module out to the console--target-dir &lt;path&gt; - will generate the new module at the provided path","ref":"Mix.Tasks.Zwave.Gen.CommandClass.html","title":"Mix.Tasks.Zwave.Gen.CommandClass","type":"task"},{"doc":"","ref":"Mix.Tasks.Zwave.Gen.CommandClass.html#get_target/1","title":"Mix.Tasks.Zwave.Gen.CommandClass.get_target/1","type":"function"},{"doc":"Callback implementation for Mix.Task.run/1.","ref":"Mix.Tasks.Zwave.Gen.CommandClass.html#run/1","title":"Mix.Tasks.Zwave.Gen.CommandClass.run/1","type":"function"},{"doc":"Exception for when decoding a Z-Wave Command goes wrong","ref":"Grizzly.ZWave.DecodeError.html","title":"Grizzly.ZWave.DecodeError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"Grizzly.ZWave.DecodeError.html#message/1","title":"Grizzly.ZWave.DecodeError.message/1","type":"function"},{"doc":"","ref":"Grizzly.ZWave.DecodeError.html#t:t/0","title":"Grizzly.ZWave.DecodeError.t/0","type":"type"},{"doc":"An Elixir library for Z-Wave","ref":"readme.html","title":"README","type":"extras"},{"doc":"def deps do [ {:grizzly, &quot;~&gt; 0.10.3&quot;} ] end","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"Z-Wave Bridge ControllerZ-Wave 500Z-Wave 700Nerves Compatible SystemSilicon Labs zipgateway binaryThe zipgateway binary allows Grizzly to use Z-Wave over IP or Z/IP. Using the zipgateway binary provided by Silicon labs allows Grizzly to support the full range of Z-Wave features quickly and reliability. Some of the more advanced features like S2 security and smart start are already supported in Grizzly.See instructions for compiling the zipgateway binary.","ref":"readme.html#hardware-requirements","title":"README - Hardware Requirements","type":"extras"},{"doc":"To use a device you have to add it to the Z-Wave network. This is &quot;called including a device&quot; or &quot;starting an inclusion.&quot; While most of the Grizzly's API is synchronous the process of adding a node is not. So, if you are working from the IEx console you can use flush to see the newly add device. Here's how this process roughly goes.iex&gt; Grizzly.Inclusions.add_node() :ok iex&gt; flush %Grizzly.ZWave.Command{ name: :node_add_status, .... params: [&lt;node info in here&gt;] }To remove a device we have to do an exclusion. Z-Wave uses the umbrella term &quot;inclusions&quot; for both adding a removing a device, but an &quot;inclusion&quot; is only about device pairing and &quot;exclusion&quot; is only about device removal. The way to remove the device from your network in IEx:iex&gt; Grizzly.Inclusions.remove_node() :ok iex&gt; flush %Grizzly.ZWave.Command{ name: :node_remove_status ... params: [&lt;information about exclusion&gt;] }There are more details about this process and how to better tie into the Grizzly runtime for this events in Grizzly.Inclusions.After you included a node it will be given a node id that you can use to send Z-Wave commands to it. Say for example we added an on off switch to our network, in Z-Wave this will be called a binary switch, and it was given the id of 5. Turning it off and on would look like this in IEx:iex&gt; Grizzly.send_command(5, :switch_binary_set, target_value: :on :ok iex&gt; Grizzly.send_command(5, :switch_binary_set, target_value: :off) :okGrizzly.send_command/3 can return a few responses.Successful Commands:ok - normally for setting things on a device or changing the device's state{:ok, Grizzly.ZWave.Command.t()} - this is normally returned when asking for a device state or about some information about a device or Z-Wave network{:queued, reference, queue_time} - some devices sleep, so sending a command to it will be queued for some queue_time. Once the device wakes up and handles the queued command the calling process will receive a message like: {:grizzly, :queued_command_response, reference, response} where the reference is the one that was given at the time of the call, and the response one of the two above responses depending on the command that was sent.When things go wrong{:error, :timeout} - if the command times out for whatever reason{:error, :nack_response} - for when the node is not responding to the command. Grizzly has automatic retries, so if you got this message that might mean the node is reachable, your Z-Wave network is experiencing a of traffic, or the node has recently been hit with a lot of commands and cannot handle anymore at this moment.More information about Grizzly.send_command/3 and the options like timeouts and retries that can be passed to see the Grizzly module.","ref":"readme.html#basic-usage","title":"README - Basic Usage","type":"extras"},{"doc":"The Grizzly runtime is a module that manages the set up operations of the Z-Wave IP stack.Z-Wave is ReadyWhen the Z-Wave stack is completely set up Grizzly will call the :on_ready module function arg callback that is configured for the runtime. To configure this add this to your config.exs file:config :grizzly, runtime: [ on_ready: {MyModule, :zwave_up, []} ]In most cases this all the configuration you need for the runtime.Advanced Runtime ConfigurationBy default the Grizzly runtime handle setting the zipgateway binary and generate the correct configuration files or it to run and network correctly. The nice things about this default setup is Grizzly leverages OTP to supervise the zipgateway binary, and if the binary crashes Grizzly will restart it.However, there are use cases for needing to manage the zipgateway binary outside of Grizzly. So if you plan on starting zipgateway outside of Grizzly you can configure the runtime like:config :grizzly, runtime: [ run_zipgateway_bin: false ]For more information see Grizzly.Runtime module","ref":"readme.html#grizzly-runtime","title":"README - Grizzly Runtime","type":"extras"},{"doc":"Grizzly defers the low-level Z-Wave protocol handling to a combination of third party software and hardware. The software is silicon Labs' zipgateway and the hardware is a Silicon Labs Z-Wave bridge.Configure the Z-Wave BridgeDifferent systems will use different serial ports to talk to the Z-Wave bridge. In order to configure this, there is a serial_port option. Below is an example for the Raspberry PI 3:config :grizzly, serial_port: &quot;/dev/ttyACM0&quot;If you are using a base nerves system please see the documentation for your particular system at the Nerves Project github page.Compile and Configure zipgatewayFirst download the Z/IP GW SDK from Silicon Labs. You'll need to create an account with them to do this, but the download is free.The default binaries that come with the download will not work by default in Nerves system, so you will need to compile the source for your target. The source code can be found in the Source directory.This can be tricky and the instructions are a work in progress, so for now please contact us if you any troubles.Connecting zipgateway to Grizzlyzipgateway runs as a separate server, accessed over a DTLS (UDP over SSL) connection. Grizzly will automatically start this server. It assumes the executable is in /usr/sbin/zipgateway. If this is not the case, you can specify the actual location withconfig :grizzly, zipgateway_path: &quot;«path»&quot;Grizzly uses the taptun module to manage the TCP connection: it checks that this is loaded as it starts.Configuring zipgatewayThe zipgateway binary is passed a configuration file named zipgateway.cfg. This has configuration parameters around networking and setting device specific information. Most of these configuration settings are static, so Grizzly can handle those for you in a reliable way. However, there are few exposed configuration options to allow some customization around device specific information, logging, and network interface set up.Supported configuration fields are::tun_script - a path to the .tun script (default priv dir of Grizzly):manufacturer_id: Id to set in the version report (default 0):hardware_version - Hardware version to set in the version report (default 1):product_id - Id to set in the version report (default 1):product_type - Id to set in the version report (default 1):serial_log - Log file for serial communication. Used for debugging. If this option is not set the no logging is done (default none)For the most part if you are using Grizzly to run zipgateway the defaults should just work.When going through certification you will need provide some device specific information:config :grizzly, zipgateway_cfg: %{ manufacturer_id: 0, product_type: 1, product_id: 1, hardware_version: 1 }The manufacturer_id will be given to you by Silicon Labs, and will default to 0if not set (this is zipgateway level default).The above fields have no impact on the Grizzly runtime, and are only useful for certification processes.When running zipgateway binary out side of Grizzly this configuration field is ignored and you will need to pass in the location to your configuration like so:zipgateway -c /path/to/zipgateway.cfg","ref":"readme.html#z-wave-bridge-configuration","title":"README - Z-Wave Bridge Configuration","type":"extras"},{"doc":"Z-Wave Specification DocumentationZ-Wave Learning ResourcesSpecific Z-Wave product information","ref":"readme.html#resources","title":"README - Resources","type":"extras"},{"doc":"","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"","ref":"changelog.html#changelog","title":"CHANGELOG - Changelog","type":"extras"},{"doc":"EnhancementsAdd handle_timeout/2 to the Grizzly.InclusionHandler behaviour. This allows for handling when an inclusion process timesout.Add Grizzly.Inclusions.stop/0 force stop any type of inclusion process.Add Grizzly.FirmwareUpdates module for updating the Z-Wave firmware on Z-Wave hardwareFixesnot parsing command classes correctly on Grizzly.ZWave.Commands.NodeAddStatusNot stopping an inclusion process correctly when calling Grizzly.Inclusions.add_node_stop/0Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-10-3","title":"CHANGELOG - v0.10.3","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.FailedNodeRemoveAdd Grizzly.ZWave.Commands.FailedNodeRemoveStatusFixesSensor types returned from the support sensors reportBroken link in docsThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v-0-10-2","title":"CHANGELOG - v.0.10.2","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.ConfigurationGetAdd Grizzly.ZWave.Commands.ConfigurationReportThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v-0-10-1","title":"CHANGELOG - v.0.10.1","type":"extras"},{"doc":"Removed the parameter :secure_command_classes from Grizzly.ZWave.Command.NodeInfoCacheReport. Also updated the param :command_classes to be a keyword list of the various command classes that the node can have.The fields in the keyword list are::non_secure_supported:non_secure_controlled:secure_supported:secure_controlledIf you are using :secure_command_classes for checking if the device is securely added you can update like this: {:ok, node_info} = Grizzly.Node.get_info(10) Keyword.get(Grizzly.ZWave.Command.param!(node_info, :command_classes), :secure_controlled)EnhancementsAdd Grizzly.ZWave.Commands.AssociationGroupCommandListGetAdd Grizzly.ZWave.Commands.AssociationGroupCommandListReportAdd Grizzly.ZWave.Commands.AssociationGroupInfoGetAdd Grizzly.ZWave.Commands.AssociationGroupInfoReportAdd Grizzly.ZWave.Commands.AssociationGroupNameGetAdd Grizzly.ZWave.Commands.AssociationGroupNameReportAdd Grizzly.ZWave.Commands.MultiChannelEndpointGetAdd Grizzly.ZWave.Commands.MultiChannelEndpointReportFixesInternal command class name discrepanciesThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-10-0","title":"CHANGELOG - v0.10.0","type":"extras"},{"doc":"The official v0.9.0 release!If you trying to upgrade from v0.8.x please see Grizzly v0.8.0 -&gt; v0.9.0 guide and follow the Changelog from the initial v0.9.0-rc.0 release.Changes from the last rc are:EnhancementsSupport Erlang 23.0 with Elixir 1.10Dep updates and tooling enhancementsFixesmiss spellings of command namesThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0","title":"CHANGELOG - v0.9.0","type":"extras"},{"doc":"EnhancementsAdd Grizzly.ZWave.Commands.FirmwareMDGetAdd Grizzly.ZWave.Commands.FirmwareUpdateMDRequestGetAdd Grizzly.ZWave.Commands.FirmwareUpdateMDRequestReportAdd Grizzly.ZWave.Commands.FirmwareUpdateMDStatusReportAdd Grizzly.ZWave.Commands.FirmwareUpdateMDReportAdd Grizzly.ZWave.Commands.FirmwareUpdateActivationSetAdd Grizzly.ZWave.Commands.FirmwareUpdateActivationReportRemove some dead codeFixesWhen resetting the controller we were not closing the connections to the nodes. This caused some error logging in zipgateway and also left open unused resources. This could cause problems later when reconnecting devices to resources that were already in the system.Thank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0-rc-4","title":"CHANGELOG - v0.9.0-rc.4","type":"extras"},{"doc":"EnhancementsSome Z-Wave devices report the wrong value for the switch multilevel report so we added support for those values.FixesWhen two processes quickly sent the same command to the same device only one process would receive the responseThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0-rc-3","title":"CHANGELOG - v0.9.0-rc.3","type":"extras"},{"doc":"DeprecatedGrizzly.Node.get_node_info/1 - use Grizzly.Node.get_info/1 insteadAddedGrizzly.Node.get_info/1Grizzly.ZWave.CommandClasses.SupervisionGrizzly.ZWave.Commands.SupervisionGetGrizzly.ZWave.Commands.SupervisionReportGrizzly.ZWave.CommandClasses.SensorBinaryGrizzly.ZWave.Commands.SensorBinaryGetGrizzly.ZWave.Commands.SensorBinaryReportEnhancementsSupport for DoorLockOperationReport &gt;= V3 parsingFixesBad parsing of NodAddStatus :failed valueThank you to those who contributed to this release:Jean-Francois Cloutier","ref":"changelog.html#v0-9-0-rc-2","title":"CHANGELOG - v0.9.0-rc.2","type":"extras"},{"doc":"Breaking ChangesGrizzly.ZWave.IconTypes removed icon_type from the atom values of the icon name.Grizzly.ZWave.DeciveTypes.icon_name() -&gt; Grizzly.ZWave.DeviceTypes.name()Grizzly.ZWave.DeciveTypes.icon_integer() -&gt; Grizzly.ZWave.DeviceTypes.value()EnhancementsDoc updatesInternal code qualityDeps updatesBetter types around DSKsCI support for elixir versions 1.8, 1.9, and 1.10Support all versions of the meter reportSupport a low battery report","ref":"changelog.html#v0-9-0-rc-1","title":"CHANGELOG - v0.9.0-rc.1","type":"extras"},{"doc":"For more detailed guide to the breaking changes and how to upgrade please see our Grizzly v0.8.0 -&gt; v0.9.0 guide.This release presents a simpler API, faster boot time, more robustness in Z-Wave communication, and resolves all open issues on Grizzly that were reported as bugs.Removed APIsGrizzly.Node structGrizzly.Conn moduleGrizzly.Notifications moduleGrizzly.Packet moduleGrizzly.close_connectionGrizzly.command_class_versions_known?Grizzly.update_command_class_versionsGrizzly.start_learn_modeGrizzly.get_command_class_versionGrizzly.has_command_classGrizzly.connected?Grizzly.has_command_class_namesGrizzly.configGrizzly.Network.busy?Grizzly.Network.ready?Grizzly.Network.get_stateGrizzly.Network.set_stateGrizzly.Network.get_nodeGrizzly.Node.newGrizzly.Node.updateGrizzly.Node.put_ipGrizzly.Node.get_ipGrizzly.Node.connectGrizzly.Node.disconnectGrizzly.Node.make_configGrizzly.Node.has_command_class?Grizzly.Node.connected?Grizzly.Node.command_class_namesGrizzly.Node.update_command_class_versionsGrizzly.Node.get_command_class_versionGrizzly.Node.command_class_version_known?Grizzly.Node.update_command_classGrizzly.Node.put_associationGrizzly.Node.get_association_listGrizzly.Node.configure_associationGrizzly.Node.get_network_informationGrizzly.Node.initialize_command_versionsMoved APIsGrizzly.reset_controller -&gt; Grizzly.Network.reset_controllerGrizzly.get_nodes -&gt; Grizzly.Network.get_node_idsGrizzly.get_node_info -&gt; Grizzly.Node.get_node_infoGrizzly.Notifications.subscribe -&gt; Grizzly.subscribe_command and Grizzly.subscribe_commandsGrizzly.Notifications.unsubscribe -&gt; Grizzly.unsubscribeGrizzly.add_node -&gt; Grizzly.Inclusions.add_nodeGrizzly.remove_node -&gt; Grizzly.Inclusions.remove_nodeGrizzly.add_node_stop -&gt; Grizzly.Inclusions.add_node_stopGrizzly.remove_node_stop -&gt; Grizzly.Inclusions.remove_node_stopGrizzly.Client -&gt; Grizzly.TransportGrizzly.Security -&gt; Grizzly.ZWave.SecurityGrizzly.DSK -&gt; Grizzly.ZWave.DSKGrizzly.Node.add_lifeline_group -&gt; Grizzly.Node.set_lifeline_associationWe moved all the commands and command classes to be under the the Grizzly.ZWave module namespace and refactored the command behaviour.Grizzly.send_command ChangesThe main API function to Grizzly has changed in that it only takes a node id, command name (atom), command args, and command options.Also it no longer returns a plain map when there is data to report back from a Z-Wave node but it will return {:ok, %Grizzly.ZWave.Command{}}.Please see Grizzly and Grizzly.ZWave.Command docs for more information.ConnectionsGrizzly uses the zipgateway binary under the hood. The binary has its own networking stack and provides a DTLS server for us to connect to. Prior to Grizzly v0.9.0 we greatly exposed that implementation detail. However, starting in Grizzly v0.9.0 we have hidden that implementation detail away and all connection functionally is handle by Grizzly internally. This leaves the consumer of Grizzly to just work about sending and receiving commands.If you are using %Grizzly.Conn{} directly this is no longer available and you should upgrade to just using the node id you were sending commands to.When Grizzly is ReadyWe use to send a notification to let the consumer to know when Grizzly is read. Staring in v0.9.0 the consumer needs to configure Grizzly's runtime with the on_ready module, function, arg callback.config :grizzly, runtime: [ on_ready: {MyApp, :some_function, []} ]See Grizzly.Runtime for more detailsInclusion Handler BehaviourAdding and removing a Z-Wave node can be a very interactive process that involves users being able to talk to the including controller and device. The way Grizzly &lt; v0.9.0 did it wasn't vary useful or robust. By adding the the inclusion handler behaviour we allow the consumer to have full control over the inclusion process, enabling closer to Z-Wave specification inclusion process.See Grizzly.InclusionHandler and Grizzly.Inclusions for more information.Command Handler BehaviourIf you need to handle a Z-Wave command lifecycle differently than the default Grizzly implementation you can make your own handler and pass it into Grizzly.send_command as an option:Grizzly.send_command(node_id, :switch_binary_set, [value: :on], handler: MyHandler)See Grizzly.CommandHandler for more information.Supporting CommandsAt the point of the rc.0 release are not fully 100% supporting the same commands as in &lt; v0.8.8, but we are really close. The commands that we haven't pulled over are not critical to average Z-Wave device control. We will work to get all the commands back into place.Thank you to Jean-Francois Cloutier for contributing so much to this release.","ref":"changelog.html#v0-9-0-rc-0","title":"CHANGELOG - v0.9.0-rc.0","type":"extras"},{"doc":"EnhancementsMake Z-Wave versions standard version formattingFixesParing the FirmwareMD report for version 5Fix spec for queued commands","ref":"changelog.html#v0-8-8","title":"CHANGELOG - v0.8.8","type":"extras"},{"doc":"EnhancementsSupport FIRMWARE_UPDATE_MD meta data report command v5","ref":"changelog.html#v0-8-7","title":"CHANGELOG - v0.8.7","type":"extras"},{"doc":"Fixesduplicate fields on the Grizzly.Node struct","ref":"changelog.html#v0-8-6","title":"CHANGELOG - v0.8.6","type":"extras"},{"doc":"Fixesvarious spelling and documentation fixesdialzyer fixes","ref":"changelog.html#v0-8-5","title":"CHANGELOG - v0.8.5","type":"extras"},{"doc":"FixesHandle when there are no nodes in the node provisioning list when requesting all the DSKs.","ref":"changelog.html#v0-8-4","title":"CHANGELOG - v0.8.4","type":"extras"},{"doc":"EnhancementsSupport Wake Up v2 and Multi Channel Association v3","ref":"changelog.html#v0-8-3","title":"CHANGELOG - v0.8.3","type":"extras"},{"doc":"EnhancementsSupport SWITCH_BINARY_REPORT version 2","ref":"changelog.html#v0-8-2","title":"CHANGELOG - v0.8.2","type":"extras"},{"doc":"EnhancementsUpdate docs and resourcesFixesAn issue when the unsolicited message server would cause a no match error that propagated up the supervision treeThank you to those who contributed to this release:Ryan Winchester","ref":"changelog.html#v0-8-1","title":"CHANGELOG - v0.8.1","type":"extras"},{"doc":"Adds support for handling SmartStart meta extension fields.These fields give more information about the current status, inclusion methods, and product information for the SmartStart device.There are two breaking changes:All SmartStart meta extensions were moved from Grizzly.CommandClass.NodeProvisioning namespace into the Grizzly.SmartStart.MetaExtension namespace.Upon finalizing the meta extension behaviour and API we made changes to how previously supported meta extensions worked. Namely, we added a new/1 callback that does parameter validation, and returns {:ok, MetaExtension.t()}. This breaks the pervious behaviour of to_binary/1 functions in perviously implemented meta extensions.EnhancementsFull support for SmartStart meta extensionsAdd meta_extensions field to Grizzly.CommandClass.NodeProvisioning commands that can handle meta extensionsUpdate Grizzly.Conn.Server.Config docsFixesInvalid keep alive (heart beat) intervalSet correct constraints on Time command offset valuesThank you to those who contributed to this release:Jean-Francois CloutierRyan Winchester","ref":"changelog.html#v0-8-0","title":"CHANGELOG - v0.8.0","type":"extras"},{"doc":"Introduces SmartStart support!SmartStart will allow you to pair a device to a Z-Wave controller with out turning the device on. Devices that support SmartStart will have a device specific key (DSK) that you can provide to the controller prior to turning on the device.iex&gt; Grizzly.send_command(Grizzly.Controller, Grizzly.CommandClass.NodeProvisioning.Set, dsk: dsk) :okAfter running the above command you can plug in your SmartStart device and the controller will try to join the Z-Wave network automatically.As a note, your controller might not have the necessary firmware to have SmartStart.To verify this you can use RingLogger to read zipgateway logs which at the start will log if the controller supports SmartStart.Breaking ChangesBreaking change to the return value of sending Grizzly.CommandClass.ZipNd.InvNodeSolicitation.When using that function send_command would return {:ok, {:node_ip, node_id, ip_address}} but now it returns {:ok, %{ip_address: ip_address, node_id: node_id, home_id: home_id}}.EnhancementsSmartStart support through the NodeProvisioning command classAdded home_id field to Grizzly.Node.t()Support fetching home_id of the Z-Wave nodes when fetching Z-Wave information about the node","ref":"changelog.html#v0-7-0","title":"CHANGELOG - v0.7.0","type":"extras"},{"doc":"FixesApplication start failure when providing the correct data structure to the zipgateway_cfg configuration field","ref":"changelog.html#v0-6-6","title":"CHANGELOG - v0.6.6","type":"extras"},{"doc":"EnhancementsSupport GetDSK commandSupport FailedNodeRemove commandAllow zipgateway_path configurationGenerate the zipgateway.cfg to allow device specific information to be passed into the zipgateway runtime.","ref":"changelog.html#v0-6-5","title":"CHANGELOG - v0.6.5","type":"extras"},{"doc":"EnhancementsValidation of UserCode arguments to help ensure usage of Grizzly follows the Z-Wave specification","ref":"changelog.html#v0-6-4","title":"CHANGELOG - v0.6.4","type":"extras"},{"doc":"EnhancementsSupports AssociationGroupInformation Command Class","ref":"changelog.html#v0-6-3","title":"CHANGELOG - v0.6.3","type":"extras"},{"doc":"EnhancementsRemove the dependence on pidof allowing grizzly to work on any nerves device without the need of busyboxv0.6.1EnhancementsUpdate commands IntervalGet and ManufacturerSpecificGet to be more consistentBetter handling of invalid ManufacturerSpecific info received from devicesv0.6.0Changed Grizzly.CommandClass.CommandClassVersion to Grizzly.CommandClass.Version and changed Grizzly.ComamndClass.CommandClassVersion.Get to Grizzly.CommandClass.Version.CommandClassGet as these names reflect the Z-Wave specification better.If you only have used Grizzly.get_command_class_version/2 and the related function in Grizzly.Node module this change should not effect you.EnhancementsAdd support for:MultiChannelAssociation Command ClassWakeUp Command Class NoMoreInformation commandComplete Association Command ClassZwaveplusInfo Command ClassVersion Get CommandClean up docsRenamed Grizzly.CommandClass.CommandClassVersion to Grizzly.CommandClass.VersionRenamed Grizzly.CommandClass.CommandClassVersion.Get to Grizzly.CommandClass.Version.CommandClassGetv0.5.0Introduces Grizzly.Command.EncodeError exception and updates encoding and decoding functions to return tagged tuples. We now use these things when trying to send a command via Grizzly.send_command/3 so if you have invalid command arguments we can provide useful error handling with {:error, Grizzly.Command.EncodeError.t()}. The EncodeError.t() implements Elixir's exception behaviour so you can leverage the standard library to work with the exception.Unless you have implemented custom commands or used one of the many command encoders or decodes explicitly this update should not affect you too much. If you have used the encoder/decoders explicitly please see the documentation for the ones you have used to see the updated API. If you have written a command we encourage you to validate the arguments and return the {:error, EncodeError.t()} to improve the usability of and robustness your command. The new Grizzly.Command.Encoding module provides some useful functionality for validating specs for command arguments.EnhancementsProvide command argument validation and error handling via Grizzly.Command.EncodeError.()Update all the command arg encoder/decoder to use tagged tuples for better handling of invalid command argumentsIntroduces new Grizzly.Command.Encoding modules for helping validate command arugment specificationsFixesCrashes when providing invalid command argumentsv0.4.3EnhancementsSupport Powerlevel command classDoc clean upGrizzly.send_command/2 and Grizzly.send_command/3 can be passed a node id instead of a node.v0.4.2EnhancementsSupport NoOperation command classv0.4.1EnhancementsAdd support for Network Management Installation MaintenanceUpdates to docs and examplesv0.4.0Changed how configuration works.Grizzly now requires the serial port to be configured:config :grizzly, serial_port: &quot;/dev/ttyACM0&quot;Also added the pidof_bin configuration option to allow official Nerves systems to work with some of the Grizzly scripts the call that utility by using the busybox package and pointing to the executable of pidof that is compiled with busybox.If you are using a custom system you can add that utility to the busybox config, and not need to use this configuration option.config :grizzly, pidof_bin: &quot;/srv/erlang/lib/busybox-0.1.2/priv/bin/pidof&quot;Double check the version of busybox you are using and make sure that version matches the version in the pidof_bin path.Changed run_grizzly_bin to run_zipgateway_bin.","ref":"changelog.html#v0-6-2","title":"CHANGELOG - v0.6.2","type":"extras"},{"doc":"EnhancementsImplement multilevel sensor command to get supported sensor types","ref":"changelog.html#v0-3-1","title":"CHANGELOG - v0.3.1","type":"extras"},{"doc":"The big change here is removing the in memory cache for devices on the network. Most common use cases will be for a consuming application to hold on to the network device information and apply some costume logic to now that is managed.Also, we would have to keep both the external and internal cache in sync, which is really hard and was creating an odd event based system, which also lends itself to complexity.Breaking ChangesGrizzly.list_nodes() -&gt; Grizzly.get_nodes()This is mostly because before we were listing nodes from a cache, and now we are getting nodes from the Z-Wave network.Also with get_nodes we don't automatically connect to the nodes. So getting and connecting to all nodes on the Z-Wave network might look something like this:def get_and_connect() do case Grizzly.get_nodes() do {:ok, nodes} -&gt; Enum.map(nodes, &amp;Grizzly.Node.connect/1) error -&gt; error end endGrizzly.update_command_class_versions/2 -&gt; Grizzly.update_command_class_versions/1Before we would pass if the update would be async or not after reviewing how this gets used it made sense to always do it sync. Also it returns a Node.t() now with the command classes updated with the version.This is the same change found in Grizzly.Node.update_command_class_versionsGrizzly.command_class_version/3 -&gt; Grizzly.get_command_class_version/2Removed the use_cache param as there is no longer a cache.Same change found in Grizzly.Node.get_command_class_versionEnhancementsSupport Grizzly.CommandClass.Time command classSupport Grizzly.CommandClass.TimeParameters GET and SET commandsSupport Grizzly.CommandClass.ScheduleEntryLock command classGrizzly.Notifications.subscribe_all/1 - subscribe to many notifications at onceGrizzly.CommandClass.name/1 - get the name of the command classGrizzly.CommandClass.version/1 - get the version of the command classGrizzly.Network.get_nodes/0 - get the nodes on the networkGrizzly.Network.get_node/1 - get a node by node id from the networkGrizzly.Network.get_node_info/1 - get node information about a node via node idGrizzly.Node.get_ip/1 - can now take either a Node.t() or a node idUpdatesDocs and type clean upFixesTimeout when getting command class versions","ref":"changelog.html#v0-3-0","title":"CHANGELOG - v0.3.0","type":"extras"},{"doc":"UpdatesSupport for the time command classFixesTime-boxing of getting a command class version","ref":"changelog.html#v0-2-1","title":"CHANGELOG - v0.2.1","type":"extras"},{"doc":"FixesLogging with old ZipGateway label is now GrizzlyFix queued API from {ZipGateway, :queued_response, ref, response} to {Grizzly, :queued_response, ref, response}Fix timeout error when waiting for DTLS server from the zipgateway side","ref":"changelog.html#v0-2-0","title":"CHANGELOG - v0.2.0","type":"extras"}]